@@ -260,7 +260,7 @@ rst_epilog = """\
 .. _issues: https://gitlab.com/tango-controls/pytango/issues
 .. _PRs: https://gitlab.com/tango-controls/pytango/-/merge_requests
 .. _Conda-forge: https://anaconda.org/conda-forge/pytango
-.. _Mambaforge: https://github.com/conda-forge/miniforge#mambaforge
+.. _Miniforge3: https://github.com/conda-forge/miniforge#miniforge3
 .. _Miniconda: https://docs.conda.io/en/latest/miniconda.html
 
 """
@@ -268,14 +268,13 @@ rst_epilog = """\
 # -- Options for reference to other documentation ------------------------------
 
 intersphinx_mapping = {
-    "https://docs.python.org/dev": None,
-    "https://docs.scipy.org/doc/scipy": None,
-    "https://numpy.org/doc/stable": None,
-    "https://ipython.org/ipython-doc/stable": None,
-    "https://pymongo.readthedocs.io/en/stable": None,
-    "https://couchdb-python.readthedocs.io/en/latest": None,
-    "https://pycassa.github.io/pycassa": None,
-    "https://docs.sqlalchemy.org/en/latest": None,
+    "python": ("https://docs.python.org/3", None),
+    "numpy": ("https://numpy.org/doc/stable", None),
+    "ipython": ("https://ipython.org/ipython-doc/stable", None),
+    "pymongo": ("https://pymongo.readthedocs.io/en/stable", None),
+    "couchdb": ("https://couchdb-python.readthedocs.io/en/latest", None),
+    "pycassa": ("https://pycassa.github.io/pycassa", None),
+    "sqlalchemy": ("https://docs.sqlalchemy.org/en/latest", None),
 }
 
 todo_include_todos = True
