@@ -31,12 +31,12 @@ print(t)
 print(gmt)
 print(noon, noon.name, noon.value)
 if noon == noon.AM:
-    print('Good morning!')
+    print("Good morning!")
 print(clock.ctime(t))
 print(clock.mktime(gmt))
 print(display, display.name, display.value)
 clock.display = display.ANALOG
-clock.display = 'DIGITAL'  # you can use a valid string to set the value
+clock.display = "DIGITAL"  # you can use a valid string to set the value
 print(clock.display, clock.display.name, clock.display.value)
 display_type = type(display)  # or even create your own IntEnum type
 analog = display_type(0)
