@@ -2,7 +2,7 @@ import tango
 from tango.server import Device
 from tango.server import attribute
 
-__all__ = ("FwdServer", "main")
+__all__ = "FwdServer"
 
 
 class FwdServer(Device):
@@ -20,7 +20,7 @@ class FwdServer(Device):
         self._current = 0.0
         self.set_state(tango.DevState.ON)
 
-    voltage = attribute(name="voltage", label="Voltage", forwarded=True)
+    voltage = attribute(forwarded=True)
 
     @attribute(label="Current", dtype="float")
     def current(self):
