@@ -13,11 +13,7 @@ from tango.server import Device, attribute, command
 
 
 class PowerSupply(Device):
-
-    @attribute(
-        dtype=float,
-        polling_period=3000,  # milliseconds
-        rel_change=1e-3)
+    @attribute(dtype=float, polling_period=3000, rel_change=1e-3)  # milliseconds
     def voltage(self):
         noise = -0.05 + 0.1 * random.random()
         return 1.5 + noise
@@ -27,5 +23,5 @@ class PowerSupply(Device):
         sleep(0.1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     PowerSupply.run_server()
