@@ -14,7 +14,7 @@ from tango.server import Device, attribute, command, device_property
 
 def connect(host, port):
     sock = create_connection((host, port))
-    return sock.makefile('rwb', newline=b'\n', buffering=0)
+    return sock.makefile("rwb", newline=b"\n", buffering=0)
 
 
 def write_readline(conn, msg):
@@ -23,8 +23,7 @@ def write_readline(conn, msg):
 
 
 class PowerSupply(Device):
-
-    host = device_property(str, default_value='localhost')
+    host = device_property(str, default_value="localhost")
     port = device_property(int, default_value=45000)
 
     def init_device(self):
@@ -33,14 +32,14 @@ class PowerSupply(Device):
 
     @attribute(dtype=float)
     def voltage(self):
-        return float(write_readline(self.conn, b'VOL?\n'))
+        return float(write_readline(self.conn, b"VOL?\n"))
 
     @command
     def calibrate(self):
-        write_readline(self.conn, b'CALIB 1\n')
-        while int(write_readline(self.conn, b'stat?\n')):
+        write_readline(self.conn, b"CALIB 1\n")
+        while int(write_readline(self.conn, b"stat?\n")):
             sleep(0.1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     PowerSupply.run_server()
