@@ -10,11 +10,12 @@
 ******************************************************************************/
 
 #include "precompiled_header.hpp"
-#include <tango.h>
+#include <tango/tango.h>
 #include "pyutils.h"
 
 using namespace boost::python;
 
+
 namespace PyApiUtil
 {
     inline object get_env_var(const char *name)
