@@ -204,7 +204,7 @@ struct StdString_from_python_str_unicode
       if (PyUnicode_Check(obj))
       {
           decref = true;
-          obj = PyUnicode_AsLatin1String(obj);
+          obj = EncodeAsLatin1(obj);
       }
 
       const char* value = PyBytes_AsString(obj);
