@@ -46,7 +46,7 @@ struct PyAttrWrittenEvent {
 };
 
 
-static void copy_most_fields(PyCallBackAutoDie* self, const Tango::CmdDoneEvent* ev, PyCmdDoneEvent* py_ev)
+static void copy_most_fields(PyCallBackAutoDie* _self, const Tango::CmdDoneEvent* ev, PyCmdDoneEvent* py_ev)
 {
     // py_ev->device
     py_ev->cmd_name = object(ev->cmd_name);
@@ -56,21 +56,21 @@ static void copy_most_fields(PyCallBackAutoDie* self, const Tango::CmdDoneEvent*
     // py_ev->ext = object(ev->ext);
 }
 
-static void copy_most_fields(PyCallBackAutoDie* self, const Tango::AttrReadEvent* ev, PyAttrReadEvent* py_ev)
+static void copy_most_fields(PyCallBackAutoDie* _self, const Tango::AttrReadEvent* ev, PyAttrReadEvent* py_ev)
 {
     // py_ev->device
     py_ev->attr_names = object(ev->attr_names);
 
     PyDeviceAttribute::AutoDevAttrVector dev_attr_vec(ev->argout);
     py_ev->argout = PyDeviceAttribute::convert_to_python( \
-                            dev_attr_vec, *ev->device, self->m_extract_as);
+                            dev_attr_vec, *ev->device, _self->m_extract_as);
 
     py_ev->err = object(ev->err);
     py_ev->errors = object(ev->errors);
     // py_ev->ext = object(ev->ext);
 }
 
-static void copy_most_fields(PyCallBackAutoDie* self, const Tango::AttrWrittenEvent* ev, PyAttrWrittenEvent* py_ev)
+static void copy_most_fields(PyCallBackAutoDie* _self, const Tango::AttrWrittenEvent* ev, PyAttrWrittenEvent* py_ev)
 {
     // py_ev->device
     py_ev->attr_names = object(ev->attr_names);
@@ -135,7 +135,7 @@ void PyCallBackAutoDie::unset_autokill_references()
 
 
 template<typename OriginalT, typename CopyT>
-static void _run_virtual_once(PyCallBackAutoDie* self, OriginalT * ev, const char* virt_fn_name)
+static void _run_virtual_once(PyCallBackAutoDie* _self, OriginalT * ev, const char* virt_fn_name)
 {
     AutoPythonGIL gil;
 
@@ -148,18 +148,18 @@ static void _run_virtual_once(PyCallBackAutoDie* self, OriginalT * ev, const cha
 
         // - py_ev->device = object(ev->device); No, we use m_weak_parent
         // so we get exactly the same python object...
-        if (self->m_weak_parent) {
-            PyObject* parent = PyWeakref_GET_OBJECT(self->m_weak_parent);
+        if (_self->m_weak_parent) {
+            PyObject* parent = PyWeakref_GET_OBJECT(_self->m_weak_parent);
             if (parent && parent != Py_None) {
                 py_ev->device = object(handle<>(borrowed(parent)));
             }
         }
 
-        copy_most_fields(self, ev, py_ev);
+        copy_most_fields(_self, ev, py_ev);
 
-        self->get_override(virt_fn_name)(py_value);
+        _self->get_override(virt_fn_name)(py_value);
     } catch (...) {
-        self->unset_autokill_references();
+        _self->unset_autokill_references();
         /// @todo yes, I want the exception to go to Tango and then wathever. But it will make a memory leak bcos tangoc++ is not handling exceptions properly!!  (proxy_asyn_cb.cpp, void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req,Tango::CallBack *cb_ptr))
         /// and the same for cmd_ended, attr_read & attr_written
         /// @bug See previous todo. If TangoC++ is fixed, it'll become a bug:
@@ -167,7 +167,7 @@ static void _run_virtual_once(PyCallBackAutoDie* self, OriginalT * ev, const cha
         /// @todo or maybe it's just that I am not supposed to re-throw the exception? (still a bug in tangoc++). Then also get rid of the "delete ev" line!
         throw;
     }
-    self->unset_autokill_references();
+    _self->unset_autokill_references();
 };
 
 /*virtual*/ void PyCallBackAutoDie::cmd_ended(Tango::CmdDoneEvent * ev)
