@@ -19,7 +19,7 @@ namespace PyDevError
     {
         if (PyUnicode_Check(in))
         {
-            PyObject *bytes_in = PyUnicode_AsLatin1String(in);
+            PyObject *bytes_in = EncodeAsLatin1(in);
             out = CORBA::string_dup(PyBytes_AsString(bytes_in));
             Py_DECREF(bytes_in);
         }
