@@ -147,7 +147,6 @@ namespace PyDeviceAttribute
                 Tango::DevVarCharArray& w_encoded_data_array = w_buffer.encoded_data;
                 char* w_ch_ptr = (char*) w_encoded_data_array.get_buffer();
                 PyObject* w_encoded_data_ptr = NULL;
-                    PyByteArray_FromStringAndSize(w_ch_ptr, w_encoded_data_array.length());
                 Py_ssize_t w_size = w_encoded_data_array.length();
                 if (read_only)
                 {
@@ -159,7 +158,7 @@ namespace PyDeviceAttribute
                 }
                 bopy::object w_encoded_data = bopy::object(bopy::handle<>(w_encoded_data_ptr));
 
-                py_value.attr(value_attr_name) =
+                py_value.attr(w_value_attr_name) =
                     bopy::make_tuple(w_encoded_format, w_encoded_data);
             }
         }
@@ -228,10 +227,7 @@ namespace PyDeviceAttribute
 
         Tango::DevVarCharArray& r_encoded_data_array = r_buffer.encoded_data;
         char* r_ch_ptr = (char*)r_encoded_data_array.get_buffer();
-
-        bopy::object r_encoded_data(
-            bopy::handle<>(PyBytes_FromStringAndSize(
-                r_ch_ptr, r_encoded_data_array.length())));
+        bopy::str r_encoded_data(r_ch_ptr, r_encoded_data_array.length());
 
         py_value.attr(value_attr_name) =
             bopy::make_tuple(r_encoded_format, r_encoded_data);
@@ -253,10 +249,7 @@ namespace PyDeviceAttribute
 
                 Tango::DevVarCharArray& w_encoded_data_array = w_buffer.encoded_data;
                 char* w_ch_ptr = (char*)w_encoded_data_array.get_buffer();
-
-                bopy::object w_encoded_data(
-                    bopy::handle<>(PyBytes_FromStringAndSize(
-                        w_ch_ptr, w_encoded_data_array.length())));
+                bopy::str w_encoded_data(w_ch_ptr, w_encoded_data_array.length());
 
                 py_value.attr(w_value_attr_name) =
                     bopy::make_tuple(w_encoded_format, w_encoded_data);
@@ -304,7 +297,7 @@ namespace PyDeviceAttribute
     _update_scalar_values<Tango::DEV_ENCODED>(Tango::DeviceAttribute &self,
                                               bopy::object py_value)
     {
-        _update_value_as_string<Tango::DEV_ENCODED>(self, py_value);
+        _update_value_as_bin<Tango::DEV_ENCODED>(self, py_value, true);
     }
 
     template<> inline void
@@ -671,6 +664,72 @@ namespace PyDeviceAttribute
         assert(false);
     }
 
+    template<long tangoTypeConst>
+    static inline void _fill_scalar_attribute(Tango::DeviceAttribute & dev_attr,
+                                              const boost::python::object & py_value)
+    {
+        typedef typename TANGO_const2type(tangoTypeConst) TangoScalarType;
+
+        TangoScalarType value;
+        from_py<tangoTypeConst>::convert(py_value.ptr(), value);
+        dev_attr << const_cast<TangoScalarType&>(value);
+    }
+
+    template<>
+    inline void _fill_scalar_attribute<Tango::DEV_STRING>(Tango::DeviceAttribute & dev_attr,
+                                                          const boost::python::object & py_value)
+    {
+        std::string value = from_str_to_char(py_value.ptr());
+        dev_attr << value;
+    }
+
+    template<>
+    inline void _fill_scalar_attribute<Tango::DEV_ENCODED>(Tango::DeviceAttribute & dev_attr,
+                                                           const boost::python::object & py_value)
+    {
+        if (boost::python::len(py_value) != 2) {
+            raise_(PyExc_TypeError, "Expecting a tuple of strings: encoded_format, encoded_data");
+        }
+
+        boost::python::object encoded_format_str = py_value[0];
+        boost::python::object encoded_data_str = py_value[1];
+
+        // todo second parameter of insert is a reference, and it does not take ownership of the pointer
+        // so to be 100% sure, we have to copy data. However, in this case we have to have an option to control release parameter.
+        // At the moment (cppTango 9.4.1) it is not realized, so we pass pointer to data and Python's gb destroys object
+        // this is a source of bugs. Somehow it works, but no idea why.
+
+        char* encoded_format = const_cast<char*>((boost::python::extract<const char*>(encoded_format_str)()));
+
+        Py_ssize_t encoded_data_len = boost::python::len(encoded_data_str);
+        PyObject* encoded_data_obj = encoded_data_str.ptr();
+        unsigned char* encoded_data;
+
+        if (PyUnicode_Check(encoded_data_obj))
+        {
+            Py_ssize_t size;
+            encoded_data = reinterpret_cast<unsigned char*>((char*)PyUnicode_AsUTF8AndSize(encoded_data_obj, &size));
+            dev_attr.insert(encoded_format, encoded_data, static_cast<unsigned int>(size));
+        }
+        else if (PyBytes_Check(encoded_data_obj) || PyByteArray_Check(encoded_data_obj))
+        {
+            Py_buffer view;
+
+            if (PyObject_GetBuffer(encoded_data_obj, &view, PyBUF_FULL_RO) < 0)
+            {
+                raise_(PyExc_TypeError, "Cannot convert encoded data");
+            }
+
+            encoded_data = reinterpret_cast<unsigned char*>((char*)view.buf);
+            dev_attr.insert(encoded_format, encoded_data, static_cast<unsigned int>(encoded_data_len));
+            PyBuffer_Release(&view);
+        }
+        else
+        {
+            raise_(PyExc_TypeError, "Encoded_data can be str, bytes or bytearray");
+        }
+    }
+
     static inline bopy::object
     undefined_attribute(Tango::DeviceAttribute* self)
     {
@@ -734,7 +793,6 @@ namespace PyDeviceAttribute
         }
         reset_values(self, attr_info.data_type, attr_info.data_format, py_value);
     }
-
 };
 
 void export_device_attribute()
