@@ -42,7 +42,7 @@ namespace PyDeviceData {
 	    PyObject* py_value_ptr = py_value.ptr();
 	    if(PyUnicode_Check(py_value_ptr))
 	    {
-		PyObject* obj_bytes_ptr = PyUnicode_AsLatin1String(py_value_ptr);
+		PyObject* obj_bytes_ptr = EncodeAsLatin1(py_value_ptr);
 		Tango::DevString value = PyBytes_AsString(obj_bytes_ptr);
 		self << value;
 		Py_DECREF(obj_bytes_ptr);
@@ -57,16 +57,14 @@ namespace PyDeviceData {
         template <>
         void insert_scalar<Tango::DEV_ENCODED>(Tango::DeviceData &self, object py_value)
         {
-            object p0 = py_value[0];
-            object p1 = py_value[1];
-            const char* encoded_format = extract<const char*> (p0.ptr());
-            const char* encoded_data = extract<const char*> (p1.ptr());
-            
-            CORBA::ULong nb = static_cast<CORBA::ULong>(boost::python::len(p1));
-            Tango::DevVarCharArray arr(nb, nb, (CORBA::Octet*)encoded_data, false);
             Tango::DevEncoded val;
+            object p0 = py_value[0];
+            const char* encoded_format = extract<const char*> (p0.ptr());
             val.encoded_format = CORBA::string_dup(encoded_format);
-            val.encoded_data = arr;
+
+            view_pybytes_as_char_array(py_value[1], val.encoded_data);
+            // By giving a value (not a pointer) to << the data will be copied by CORBA
+
             self << val;
         }
 
