@@ -58,7 +58,7 @@ namespace Tango
 
 void sequencePyDevError_2_DevErrorList(PyObject *value, Tango::DevErrorList &del)
 {
-    long len = max((int)PySequence_Size(value), 0);
+    long len = (std::max)((int)PySequence_Size(value), 0);
     del.length(len);
 
     for (long loop = 0; loop < len; ++loop)
@@ -177,9 +177,9 @@ Tango::DevFailed to_dev_failed(PyObject *type, PyObject *value,
 
             PyObject *tbList_ptr = PyObject_CallMethod(
                     tracebackModule,
-                    (char *)"format_tb",
-                    (char *)"O",
-                    traceback == NULL ? Py_None : traceback);
+                    (char *)"format_exception",
+                    (char *)"OOO",
+                    type, value, traceback);
             
             boost::python::object tbList = object(handle<>(tbList_ptr));
             boost::python::str origin = str("").join(tbList);
@@ -477,6 +477,6 @@ void export_exceptions()
     NamedDevFailedList
         .def("get_faulty_attr_nb", &Tango::NamedDevFailedList::get_faulty_attr_nb) // size_t
         .def("call_failed", &Tango::NamedDevFailedList::call_failed) // bool
-        .def_readonly("err_list", &Tango::NamedDevFailedList::err_list) // vector<NamedDevFailed>
+        .def_readonly("err_list", &Tango::NamedDevFailedList::err_list) // std::vector<NamedDevFailed>
     ;
 }
