@@ -140,7 +140,7 @@ struct from_sequence
             }
             else if(PyUnicode_Check(o_ptr))
             {
-                PyObject* o_bytes_ptr = PyUnicode_AsLatin1String(o_ptr);
+                PyObject* o_bytes_ptr = EncodeAsLatin1(o_ptr);
                 a.push_back(Tango::DbDatum(PyBytes_AS_STRING(o_bytes_ptr)));
                 Py_DECREF(o_bytes_ptr);
             }
