@@ -19,6 +19,34 @@ namespace bopy = boost::python;
 
 #define arg_(a) boost::python::arg(a)
 
+inline void raise_(PyObject *type, const char *message)
+{
+    PyErr_SetString(type, message);
+    boost::python::throw_error_already_set();
+}
+
+inline PyObject* EncodeAsLatin1(PyObject *in)
+{
+    PyObject* bytes_out = PyUnicode_AsLatin1String(in);
+    if (!bytes_out)
+    {
+        PyObject* bytes_replaced = PyUnicode_AsEncodedString(in, "latin-1", "replace");
+        const char* string_replaced = PyBytes_AsString(bytes_replaced);
+        std::string err_msg = "Can't encode ";
+        if (!string_replaced) {
+            err_msg += "unknown Unicode string as Latin-1";
+        } else {
+            err_msg += "'";
+            err_msg += string_replaced;
+            err_msg += "' Unicode string as Latin-1 (bad chars replaced with ?)";
+        }
+        Py_XDECREF(bytes_replaced);
+        raise_(PyExc_UnicodeError, err_msg.c_str());
+    }
+
+    return bytes_out;
+}
+
 
 inline PyObject *PyObject_GetAttrString_(PyObject *o, const std::string &attr_name)
 {
@@ -53,16 +81,18 @@ bopy::object from_char_to_boost_str(const std::string& in,
                                     const char* errors="strict");
 
 
-void from_str_to_char(const bopy::object& in, std::string& out);
-void from_str_to_char(PyObject* in, std::string& out);
+void throw_bad_type(const char *type, const char *source);
+
+char* from_str_to_char(PyObject* in,
+                       Py_ssize_t* size_out,
+                       const bool utf_encoding=false /* defaults to latin-1 */);
+char* from_str_to_char(const bopy::object& in,
+                       Py_ssize_t* size_out,
+                       const bool utf_encoding=false /* defaults to latin-1 */);
 char* from_str_to_char(PyObject* in);
 char* from_str_to_char(const bopy::object& in);
 
-inline void raise_(PyObject *type, const char *message)
-{
-    PyErr_SetString(type, message);
-    boost::python::throw_error_already_set();
-}
+void view_pybytes_as_char_array(const bopy::object& py_value, Tango::DevVarCharArray& out_array);
 
 /// You should run any I/O intensive operations (like requesting data through
 /// the network) in the context of an object like this.
