@@ -307,7 +307,55 @@ namespace PyAttribute
     { __set_value("set_value", att, value, 0, 0); }
 
     inline void set_value(Tango::Attribute &att, Tango::EncodedAttribute *data)
-    { att.set_value(data); }
+    {
+        if(data == NULL)
+        {
+            TangoSys_OMemStream description;
+            description << "Data pointer for attribute " << att.get_name() << " is NULL! Most probably set_value was called with None ";
+
+            TangoSys_OMemStream origin;
+            origin << TANGO_EXCEPTION_ORIGIN << std::ends;
+
+            Tango::Except::throw_exception(
+                    "PyDs_AttributeDataIsNULL",
+                    description.str(),
+                    origin.str());
+        }
+
+        Tango::DevString *f    = data->get_format();
+        Tango::DevUChar  *d    = data->get_data();
+        long              size = data->get_size();
+
+        if( *f==NULL )
+        {
+            TangoSys_OMemStream o;
+            o << "DevEncoded format for attribute " << att.get_name() << " not specified" << std::ends;
+
+            Tango::Except::throw_exception(
+                    "PyDs_DevEncodedFormatNotSpecified",
+                    o.str(),
+                    "set_value()");
+        }
+
+        if( size==0 || !d )
+        {
+            TangoSys_OMemStream o;
+            o << "DevEncoded data for attribute " << att.get_name() << " not specified" << std::ends;
+
+            Tango::Except::throw_exception(
+                    "PyDs_DevEncodedDataNotSpecified",
+                    o.str(),
+                    "set_value()");
+        }
+
+
+        Tango::DevString f_copy = Tango::string_dup(*f);
+
+        Tango::DevUChar* d_copy = new Tango::DevUChar[size];
+        memcpy(d_copy, d, size);
+
+        att.set_value(&f_copy, d_copy, size, true);
+    }
 
     inline void set_value(Tango::Attribute &att, bopy::str &data_str, bopy::str &data)
     { __set_value("set_value", att, data_str, data); }
@@ -787,37 +835,37 @@ void export_attribute()
 			(PyObject* (*) (Tango::Attribute &))
 			&PyAttribute::get_max_warning)
 
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, bopy::object &))
             &PyAttribute::set_value)
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, bopy::str &, bopy::object &))
             &PyAttribute::set_value)
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, bopy::str &, bopy::str &))
             &PyAttribute::set_value)
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, Tango::EncodedAttribute *))
             &PyAttribute::set_value)
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, bopy::object &, long))
             &PyAttribute::set_value)
-        .def("set_value",
+        .def("_set_value",
             (void (*) (Tango::Attribute &, bopy::object &, long, long))
             &PyAttribute::set_value)
-        .def("set_value_date_quality",
+        .def("_set_value_date_quality",
             (void (*) (Tango::Attribute &, bopy::object &, double t, Tango::AttrQuality quality))
             &PyAttribute::set_value_date_quality)
-        .def("set_value_date_quality",
+        .def("_set_value_date_quality",
             (void (*) (Tango::Attribute &, bopy::str &, bopy::str &, double t, Tango::AttrQuality quality))
             &PyAttribute::set_value_date_quality)
-        .def("set_value_date_quality",
+        .def("_set_value_date_quality",
             (void (*) (Tango::Attribute &, bopy::str &, bopy::object &, double t, Tango::AttrQuality quality))
             &PyAttribute::set_value_date_quality)
-        .def("set_value_date_quality",
+        .def("_set_value_date_quality",
             (void (*) (Tango::Attribute &, bopy::object &, double t, Tango::AttrQuality quality, long))
             &PyAttribute::set_value_date_quality)
-        .def("set_value_date_quality",
+        .def("_set_value_date_quality",
             (void (*) (Tango::Attribute &, bopy::object &, double t, Tango::AttrQuality quality, long, long))
             &PyAttribute::set_value_date_quality)
         
