@@ -76,18 +76,6 @@ void allocate_any(CORBA::Any *&any_ptr)
     }
 }
 
-void throw_bad_type(const char *type)
-{
-    TangoSys_OMemStream o;
-
-    o << "Incompatible command argument type, expected type is : Tango::" 
-      << type << std::ends;
-    Tango::Except::throw_exception(
-            "API_IncompatibleCmdArgumentType",
-            o.str(),
-            "PyCmd::extract()");
-}
-
 template<long tangoTypeConst>
 void insert_scalar(boost::python::object &o, CORBA::Any &any)
 {
@@ -102,8 +90,8 @@ void insert_scalar<Tango::DEV_STRING>(boost::python::object &o, CORBA::Any &any)
     PyObject *o_ptr = o.ptr();
     if (PyUnicode_Check(o_ptr))
     {
-        PyObject *bytes_o_ptr = PyUnicode_AsLatin1String(o_ptr);
-	any <<= PyBytes_AsString(bytes_o_ptr);
+        PyObject *bytes_o_ptr = EncodeAsLatin1(o_ptr);
+        any <<= PyBytes_AsString(bytes_o_ptr);
         Py_DECREF(bytes_o_ptr);
     }
     else if (PyBytes_Check(o_ptr))
@@ -132,28 +120,15 @@ void insert_scalar<Tango::DEV_BOOLEAN>(boost::python::object &o, CORBA::Any &any
 template<>
 void insert_scalar<Tango::DEV_ENCODED>(boost::python::object &o, CORBA::Any &any)
 {
+    Tango::DevEncoded data;
+
     bopy::object p0 = o[0];
-    bopy::object p1 = o[1];
-
     const char* encoded_format = bopy::extract<const char *> (p0.ptr());
-    
-    PyObject* data_ptr = p1.ptr();
-    Py_buffer view;
-    
-    if (PyObject_GetBuffer(data_ptr, &view, PyBUF_FULL_RO) < 0)
-    {
-        throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_ENCODED]);
-    }
-    
-    CORBA::ULong nb = static_cast<CORBA::ULong>(view.len);
-    Tango::DevVarCharArray arr(nb, nb, (CORBA::Octet*)view.buf, false);
-    Tango::DevEncoded *data = new Tango::DevEncoded;
-    data->encoded_format = CORBA::string_dup(encoded_format);
-    data->encoded_data = arr;    
-    
-    any <<= data;
+    data.encoded_format = CORBA::string_dup(encoded_format);
+    view_pybytes_as_char_array(o[1], data.encoded_data);
 
-    PyBuffer_Release(&view);
+    // By giving a value (not a pointer) to <<= the data will be copied by CORBA
+    any <<= data;
 }
 
 template<>
@@ -189,7 +164,7 @@ void extract_scalar(const CORBA::Any &any, boost::python::object &o)
     TangoScalarType data;
     
     if ((any >>= data) == false)
-        throw_bad_type(Tango::CmdArgTypeName[tangoTypeConst]);
+        throw_bad_type(Tango::CmdArgTypeName[tangoTypeConst], TANGO_EXCEPTION_ORIGIN);
 
     o = object(data);
 }
@@ -200,7 +175,7 @@ void extract_scalar<Tango::DEV_STRING>(const CORBA::Any &any, boost::python::obj
     Tango::ConstDevString data;
     
     if ((any >>= data) == false)
-        throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_STRING]);
+        throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_STRING], TANGO_EXCEPTION_ORIGIN);
 
     o = from_char_to_boost_str(data);
 }
@@ -221,7 +196,7 @@ void extract_scalar<Tango::DEV_ENCODED>(const CORBA::Any &any, boost::python::ob
     Tango::DevEncoded* data;
 
     if ((any >>= data) == false)
-        throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_ENCODED]);
+        throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_ENCODED], TANGO_EXCEPTION_ORIGIN);
 
     boost::python::str encoded_format(data[0].encoded_format);
     boost::python::object encoded_data(
@@ -270,7 +245,7 @@ void extract_array(const CORBA::Any &any, boost::python::object &py_result)
     TangoArrayType *tmp_ptr;
 
     if ((any >>= tmp_ptr) == false)
-        throw_bad_type(Tango::CmdArgTypeName[tangoArrayTypeConst]);
+        throw_bad_type(Tango::CmdArgTypeName[tangoArrayTypeConst], TANGO_EXCEPTION_ORIGIN);
 
       // For numpy we need a 'guard' object that handles the memory used
       // by the numpy object (releases it).
