@@ -187,8 +187,8 @@ void CppDeviceClass::create_pipe(std::vector<Tango::Pipe *> &pipe_list,
     pipe_list.push_back(pipe_ptr);
 }
 
-CppDeviceClassWrap::CppDeviceClassWrap(PyObject *self, const std::string &name)
-    : CppDeviceClass(name), m_self(self)
+CppDeviceClassWrap::CppDeviceClassWrap(PyObject *_self, const std::string &name)
+    : CppDeviceClass(name), m_self(_self)
 {
     init_class();
 }
