@@ -695,10 +695,10 @@ namespace PyDeviceImpl
     }
 
     void remove_attribute(Tango::DeviceImpl &self, const char *att_name,
-                          bool clean_db = true)
+                          bool free_it = false, bool clean_db = true)
     {
         std::string str(att_name);
-        self.remove_attribute(str, false, clean_db);
+        self.remove_attribute(str, free_it, clean_db);
     }
 
     void add_command(Tango::DeviceImpl &self, boost::python::object cmd_name, boost::python::object cmd_data,
@@ -846,19 +846,19 @@ namespace PyDeviceImpl
     }
 }
 
-DeviceImplWrap::DeviceImplWrap(PyObject *self, CppDeviceClass *cl,
+DeviceImplWrap::DeviceImplWrap(PyObject *_self, CppDeviceClass *cl,
                                std::string &st)
-    :Tango::DeviceImpl(cl,st), m_self(self)
+    :Tango::DeviceImpl(cl,st), m_self(_self)
 {
     Py_INCREF(m_self);
 }
 
-DeviceImplWrap::DeviceImplWrap(PyObject *self, CppDeviceClass *cl,
+DeviceImplWrap::DeviceImplWrap(PyObject *_self, CppDeviceClass *cl,
                                const char *name,
-                               const char *desc /* = "A Tango device" */,
+                               const char *_desc /* = "A Tango device" */,
                                Tango::DevState sta /* = Tango::UNKNOWN */,
                                const char *status /* = StatusNotSet */)
-    :Tango::DeviceImpl(cl, name, desc, sta, status), m_self(self)
+    :Tango::DeviceImpl(cl, name, _desc, sta, status), m_self(_self)
 {
     Py_INCREF(m_self);
 }
@@ -910,19 +910,19 @@ void DeviceImplWrap::_stop_poll_command(const std::string &cmd_name)
 
 
 
-Device_2ImplWrap::Device_2ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_2ImplWrap::Device_2ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    std::string &st)
-    :Tango::Device_2Impl(cl,st),m_self(self)
+    :Tango::Device_2Impl(cl,st),m_self(_self)
 {
     Py_INCREF(m_self);
 }
 
-Device_2ImplWrap::Device_2ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_2ImplWrap::Device_2ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    const char *name,
-                                   const char *desc /* = "A Tango device" */,
+                                   const char *_desc /* = "A Tango device" */,
                                    Tango::DevState sta /* = Tango::UNKNOWN */,
                                    const char *status /* = StatusNotSet */)
-    :Tango::Device_2Impl(cl, name, desc, sta, status), m_self(self)
+    :Tango::Device_2Impl(cl, name, _desc, sta, status), m_self(_self)
 {
     Py_INCREF(m_self);
 }
@@ -932,7 +932,7 @@ void Device_2ImplWrap::init_device()
     this->get_override("init_device")();
 }
 
-PyDeviceImplBase::PyDeviceImplBase(PyObject *self):the_self(self)
+PyDeviceImplBase::PyDeviceImplBase(PyObject *_self):the_self(_self)
 {
     Py_INCREF(the_self);
 }
@@ -969,21 +969,21 @@ PyDeviceImplBase::~PyDeviceImplBase()
 void PyDeviceImplBase::py_delete_dev()
 {}
 
-Device_3ImplWrap::Device_3ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_3ImplWrap::Device_3ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    std::string &st)
     :Tango::Device_3Impl(cl,st),
-    PyDeviceImplBase(self)
+    PyDeviceImplBase(_self)
 {
     _init();
 }
 
-Device_3ImplWrap::Device_3ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_3ImplWrap::Device_3ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    const char *name,
-                                   const char *desc /* = "A Tango device" */,
+                                   const char *_desc /* = "A Tango device" */,
                                    Tango::DevState sta /* = Tango::UNKNOWN */,
                                    const char *status /* = StatusNotSet */)
-    :Tango::Device_3Impl(cl, name, desc, sta, status),
-    PyDeviceImplBase(self)
+    :Tango::Device_3Impl(cl, name, _desc, sta, status),
+    PyDeviceImplBase(_self)
 {
     _init();
 }
@@ -1154,21 +1154,21 @@ namespace PyDevice_3Impl
 
 }
 
-Device_4ImplWrap::Device_4ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_4ImplWrap::Device_4ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    std::string &st)
     :Tango::Device_4Impl(cl,st),
-    PyDeviceImplBase(self)
+    PyDeviceImplBase(_self)
 {
     _init();
 }
 
-Device_4ImplWrap::Device_4ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_4ImplWrap::Device_4ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    const char *name,
-                                   const char *desc /* = "A Tango device" */,
+                                   const char *_desc /* = "A Tango device" */,
                                    Tango::DevState sta /* = Tango::UNKNOWN */,
                                    const char *status /* = StatusNotSet */)
-    :Tango::Device_4Impl(cl, name, desc, sta, status),
-    PyDeviceImplBase(self)
+    :Tango::Device_4Impl(cl, name, _desc, sta, status),
+    PyDeviceImplBase(_self)
 {
     _init();
 }
@@ -1332,21 +1332,21 @@ void Device_4ImplWrap::default_signal_handler(long signo)
 }
 
 
-Device_5ImplWrap::Device_5ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_5ImplWrap::Device_5ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    std::string &st)
     :Tango::Device_5Impl(cl,st),
-    PyDeviceImplBase(self)
+    PyDeviceImplBase(_self)
 {
     _init();
 }
 
-Device_5ImplWrap::Device_5ImplWrap(PyObject *self, CppDeviceClass *cl,
+Device_5ImplWrap::Device_5ImplWrap(PyObject *_self, CppDeviceClass *cl,
                                    const char *name,
-                                   const char *desc /* = "A Tango device" */,
+                                   const char *_desc /* = "A Tango device" */,
                                    Tango::DevState sta /* = Tango::UNKNOWN */,
                                    const char *status /* = StatusNotSet */)
-    :Tango::Device_5Impl(cl, name, desc, sta, status),
-    PyDeviceImplBase(self)
+    :Tango::Device_5Impl(cl, name, _desc, sta, status),
+    PyDeviceImplBase(_self)
 {
     _init();
 }
@@ -1524,8 +1524,6 @@ BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS(set_change_event_overload,
                                        Tango::DeviceImpl::set_change_event, 2, 3)
 BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS(set_archive_event_overload,
                                        Tango::DeviceImpl::set_archive_event, 2, 3)
-BOOST_PYTHON_FUNCTION_OVERLOADS(remove_attribute_overload,
-                                PyDeviceImpl::remove_attribute, 2, 3)
 
 void export_device_impl()
 {
@@ -1567,8 +1565,7 @@ void export_device_impl()
             set_archive_event_overload())
         .def("set_data_ready_event", &Tango::DeviceImpl::set_data_ready_event)
         .def("_add_attribute", &PyDeviceImpl::add_attribute)
-        .def("_remove_attribute", &PyDeviceImpl::remove_attribute,
-            remove_attribute_overload())
+        .def("_remove_attribute", &PyDeviceImpl::remove_attribute)
         .def("_add_command", &PyDeviceImpl::add_command)
         .def("_remove_command", &PyDeviceImpl::remove_command)
         //@TODO .def("get_device_class")
