@@ -175,6 +175,16 @@ public:
      */
     virtual void init_device();
 
+    /**
+     * Necessary server_init_hook implementation to call python
+     */
+    virtual void server_init_hook();
+
+    /**
+     * Executes default server_init_hook implementation
+     */
+    void default_server_init_hook();
+
     /**
      * Necessary delete_device implementation to call python
      */
@@ -302,6 +312,16 @@ public:
      */
     virtual void init_device();
 
+    /**
+     * Necessary server_init_hook implementation to call python
+     */
+    virtual void server_init_hook();
+
+    /**
+     * Executes default server_init_hook implementation
+     */
+    void default_server_init_hook();
+
     /**
      * Necessary delete_device implementation to call python
      */
@@ -429,6 +449,16 @@ public:
      */
     virtual void init_device();
 
+    /**
+     * Necessary server_init_hook implementation to call python
+     */
+    virtual void server_init_hook();
+
+    /**
+     * Executes default server_init_hook implementation
+     */
+    void default_server_init_hook();
+
     /**
      * Necessary delete_device implementation to call python
      */
