@@ -75,7 +75,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
         const int length = w*h;
         unsigned char *raw_b = new unsigned char[length];
-        unique_pointer<unsigned char> b(raw_b);
+        unique_pointer<unsigned char[]> b(raw_b);
         buffer = raw_b;
         unsigned char *p = raw_b;
         int w_bytes = w;
@@ -187,7 +187,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
         const int length = w*h;
         unsigned char *raw_b = new unsigned char[length];
-        unique_pointer<unsigned char> b(raw_b);
+        unique_pointer<unsigned char[]> b(raw_b);
         buffer = raw_b;
         unsigned char *p = raw_b;
         int w_bytes = w;
@@ -299,7 +299,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
         const int length = w*h;
         unsigned short *raw_b = new unsigned short[length];
-        unique_pointer<unsigned short> b(raw_b);
+        unique_pointer<unsigned short[]> b(raw_b);
         buffer = raw_b;
         unsigned short *p = raw_b;
         int w_bytes = 2*w;
@@ -407,7 +407,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
         const int length = w*h;
         unsigned char *raw_b = new unsigned char[length];
-        unique_pointer<unsigned char> b(raw_b);
+        unique_pointer<unsigned char[]> b(raw_b);
         buffer = raw_b;
         unsigned char *p = raw_b;
         int w_bytes = 3*w;
@@ -519,7 +519,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
 		const int length = w*h;
         unsigned char *raw_b = new unsigned char[length];
-        unique_pointer<unsigned char> b(raw_b);
+        unique_pointer<unsigned char[]> b(raw_b);
 		buffer = raw_b;
         unsigned char *p = raw_b;
         int w_bytes = 3*w;
@@ -631,7 +631,7 @@ namespace PyEncodedAttribute
         // we are sure that w and h are given by python (see encoded_attribute.py)
 		const int length = w*h;
         unsigned char *raw_b = new unsigned char[length];
-        unique_pointer<unsigned char> b(raw_b);
+        unique_pointer<unsigned char[]> b(raw_b);
 		buffer = raw_b;
         unsigned char *p = raw_b;
         int w_bytes = 4*w;
