@@ -144,10 +144,11 @@ namespace PyTango { namespace Pipe {
     template<typename T, long tangoTypeConst>
     void __append_scalar(T &obj, const std::string &name, bopy::object& py_value)
     {
-	typedef typename TANGO_const2type(tangoTypeConst) TangoScalarType;
-	TangoScalarType value;
-	from_py<tangoTypeConst>::convert(py_value, value);
-	obj << value;
+        typedef typename TANGO_const2type(tangoTypeConst) TangoScalarType;
+        TangoScalarType tg_value;
+        from_py<tangoTypeConst>::convert(py_value, tg_value);
+        Tango::DataElement<TangoScalarType> data_elt(name, tg_value);
+        obj << data_elt;
     }
 
     template<long tangoTypeConst>
@@ -477,9 +478,10 @@ namespace PyDevicePipe
 	template<typename T, long tangoTypeConst>
 	void __append_scalar(T &obj, const std::string &name, bopy::object& py_value) {
 		typedef typename TANGO_const2type(tangoTypeConst) TangoScalarType;
-		TangoScalarType value;
-		from_py<tangoTypeConst>::convert(py_value, value);
-		obj << value;
+		TangoScalarType tg_value;
+		from_py<tangoTypeConst>::convert(py_value, tg_value);
+		Tango::DataElement<TangoScalarType> data_elt(name, tg_value);
+		obj << data_elt;
 	}
 
 	template<typename T, long tangoArrayTypeConst>
