@@ -46,9 +46,9 @@ namespace PyTango { namespace Pipe {
                   public _Pipe
     {
     public:
-        PyPipe(const std::string &name, const Tango::DispLevel level, 
+        PyPipe(const std::string &_name, const Tango::DispLevel level,
                const Tango::PipeWriteType write=Tango::PIPE_READ):
-	    Tango::Pipe(name, level, write)
+	    Tango::Pipe(_name, level, write)
 	{}
 
         ~PyPipe() {}
@@ -64,8 +64,8 @@ namespace PyTango { namespace Pipe {
                    public _Pipe 
     {
     public:
-        PyWPipe(const std::string &name, const Tango::DispLevel level):
-	    Tango::WPipe(name, level)
+        PyWPipe(const std::string &_name, const Tango::DispLevel level):
+	    Tango::WPipe(_name, level)
 	{}
 
         ~PyWPipe() {}
