@@ -253,6 +253,68 @@ namespace PyWAttribute
                 "set_write_value()");
     }
 
+    inline void __check_array_length(PyObject *seq_ptr, long &x_dim, long &y_dim, const std::string &att_name)
+    {
+        long len = static_cast< long > (PySequence_Size(seq_ptr));
+
+        PyObject *first_element = PySequence_GetItem(seq_ptr, 0);
+
+        TangoSys_OMemStream o;
+        bool failed = false;
+
+        if (PySequence_Check(first_element) & !PyUnicode_Check(first_element))
+        {
+            if (y_dim > 0)
+            {
+                if (len != y_dim)
+                {
+                    o << att_name << ": cannot covert list: given dim_y" << y_dim
+                      << " is not equal to the size " << len << "of given list "  << std::ends;
+
+                    failed = true;
+
+                }
+            }
+            else
+            {
+                y_dim = len;
+            }
+            len = (long) PySequence_Size(first_element);
+        }
+        else if (y_dim > 0)
+        {
+            o << att_name << ": cannot covert list: dim_y was given for 1D list" << std::ends;
+
+            failed = true;
+        }
+
+
+        if (x_dim > 0)
+        {
+            if (len != x_dim)
+            {
+                o << att_name << ": cannot covert list: given dim_x" << x_dim
+                  << " is not equal to the size " << len << "of given list "  << std::ends;
+
+                failed = true;
+            }
+        }
+        else
+        {
+            x_dim = len;
+        }
+
+        Py_XDECREF(first_element);
+
+        if (failed)
+        {
+            Tango::Except::throw_exception(
+                    "PyDs_WrongListSizeForAttribute",
+                    o.str(),
+                    "set_value()");
+        }
+    }
+
     template<long tangoTypeConst>
     inline void __set_write_value_array(Tango::WAttribute &att,
                                         boost::python::object &seq,
@@ -262,33 +324,72 @@ namespace PyWAttribute
         typedef typename TANGO_const2arraytype(tangoTypeConst) TangoArrayType;
 
         PyObject *seq_ptr = seq.ptr();
-        long len = (long) PySequence_Size(seq_ptr);
-        twod2oned(len, x_dim, y_dim);
+        __check_array_length(seq_ptr, x_dim, y_dim, att.get_name());
 
-        TangoScalarType *tg_ptr = TangoArrayType::allocbuf(len);
+        TangoScalarType *tg_ptr;
 
-        for (long idx = 0; idx < len; ++idx)
+        // The boost extract could be used to convert:
+        // TangoScalarType val = boost::python::extract<TangoScalarType>(elt_ptr);
+        // the problem is that extract is considerably slower than our
+        // convert function which only has to deal with the specific tango
+        // data types
+
+        if (y_dim > 0)
         {
-            PyObject *elt_ptr = PySequence_GetItem(seq_ptr, idx);
+            tg_ptr = TangoArrayType::allocbuf(x_dim * y_dim);
+            for (long idy = 0; idy < y_dim; ++idy)
+            {
+
+                PyObject *row_ptr = PySequence_GetItem(seq_ptr, idy);
+
+                try
+                {
+                    for (long idx = 0; idx < x_dim; ++idx)
+                    {
+                        PyObject *elt_ptr = PySequence_GetItem(row_ptr, idx);
+                        try
+                        {
+                            TangoScalarType tg_scalar;
+                            from_py<tangoTypeConst>::convert(elt_ptr, tg_scalar);
+                            tg_ptr[idy * x_dim + idx] = tg_scalar;
+                            Py_DECREF(elt_ptr);
+                        }
+                        catch (...)
+                        {
+                            Py_DECREF(elt_ptr);
+                            delete[] tg_ptr;
+                            throw;
+                        }
+                    }
+                    Py_DECREF(row_ptr);
+                }
+                catch (...)
+                {
+                    Py_DECREF(row_ptr);
+                    throw;
+                }
 
-            // The boost extract could be used:
-            // TangoScalarType val = boost::python::extract<TangoScalarType>(elt_ptr);
-            // instead of the code below.
-            // the problem is that extract is considerably slower than our
-            // convert function which only has to deal with the specific tango
-            // data types
-            try
-            {
-                TangoScalarType tg_scalar;
-                from_py<tangoTypeConst>::convert(elt_ptr, tg_scalar);
-                tg_ptr[idx] = tg_scalar;
-                Py_DECREF(elt_ptr);
             }
-            catch(...)
+        }
+        else
+        {
+            tg_ptr = TangoArrayType::allocbuf(x_dim);
+            for (long idx = 0; idx < x_dim; ++idx)
             {
-                Py_DECREF(elt_ptr);
-                delete [] tg_ptr;
-                throw;
+                PyObject *elt_ptr = PySequence_GetItem(seq_ptr, idx);
+                try
+                {
+                    TangoScalarType tg_scalar;
+                    from_py<tangoTypeConst>::convert(elt_ptr, tg_scalar);
+                    tg_ptr[idx] = tg_scalar;
+                    Py_DECREF(elt_ptr);
+                }
+                catch (...)
+                {
+                    Py_DECREF(elt_ptr);
+                    delete[] tg_ptr;
+                    throw;
+                }
             }
         }
 
@@ -310,33 +411,72 @@ namespace PyWAttribute
 							   long x_dim, long y_dim)
     {
         PyObject *seq_ptr = seq.ptr();
-        long len = (long) PySequence_Size(seq_ptr);
-        twod2oned(len, x_dim, y_dim);
+        __check_array_length(seq_ptr, x_dim, y_dim, att.get_name());
 
-	Tango::DevString* tg_ptr = Tango::DevVarStringArray::allocbuf(len);
+	    Tango::DevString* tg_ptr;
 
-        for (long idx = 0; idx < len; ++idx)
+        // The boost extract could be used to convert:
+        // TangoScalarType val = boost::python::extract<TangoScalarType>(elt_ptr);
+        // the problem is that extract is considerably slower than our
+        // convert function which only has to deal with the specific tango
+        // data types
+
+        if (y_dim > 0)
         {
-            PyObject *elt_ptr = PySequence_GetItem(seq_ptr, idx);
+            tg_ptr = Tango::DevVarStringArray::allocbuf(x_dim * y_dim);
+            for (long idy = 0; idy < y_dim; ++idy)
+            {
+
+                PyObject *row_ptr = PySequence_GetItem(seq_ptr, idy);
+
+                try
+                {
+                    for (long idx = 0; idx < x_dim; ++idx)
+                    {
+                        PyObject *elt_ptr = PySequence_GetItem(row_ptr, idx);
+                        try
+                        {
+                            Tango::DevString tg_scalar;
+                            from_py<Tango::DEV_STRING>::convert(elt_ptr, tg_scalar);
+                            tg_ptr[idy * x_dim + idx] = Tango::string_dup(tg_scalar);
+                            Py_DECREF(elt_ptr);
+                        }
+                        catch (...)
+                        {
+                            Py_DECREF(elt_ptr);
+                            delete[] tg_ptr;
+                            throw;
+                        }
+                    }
+                    Py_DECREF(row_ptr);
+                }
+                catch (...)
+                {
+                    Py_DECREF(row_ptr);
+                    throw;
+                }
 
-            // The boost extract could be used:
-            // TangoScalarType val = boost::python::extract<TangoScalarType>(elt_ptr);
-            // instead of the code below.
-            // the problem is that extract is considerably slower than our
-            // convert function which only has to deal with the specific tango
-            // data types
-            try
-            {
-		Tango::DevString tg_scalar;
-                from_py<Tango::DEV_STRING>::convert(elt_ptr, tg_scalar);
-                tg_ptr[idx] = Tango::string_dup(tg_scalar);
-                Py_DECREF(elt_ptr);
             }
-            catch(...)
+        }
+        else
+        {
+            tg_ptr = Tango::DevVarStringArray::allocbuf(x_dim);
+            for (long idx = 0; idx < x_dim; ++idx)
             {
-                Py_DECREF(elt_ptr);
-                delete [] tg_ptr;
-                throw;
+                PyObject *elt_ptr = PySequence_GetItem(seq_ptr, idx);
+                try
+                {
+                    Tango::DevString tg_scalar;
+                    from_py<Tango::DEV_STRING>::convert(elt_ptr, tg_scalar);
+                    tg_ptr[idx] = Tango::string_dup(tg_scalar);
+                    Py_DECREF(elt_ptr);
+                }
+                catch (...)
+                {
+                    Py_DECREF(elt_ptr);
+                    delete[] tg_ptr;
+                    throw;
+                }
             }
         }
 
@@ -387,9 +527,8 @@ namespace PyWAttribute
                         o.str(),
                         "set_value()");
             }
-			long size = static_cast<long>(PySequence_Size(value.ptr()));
             TANGO_CALL_ON_ATTRIBUTE_DATA_TYPE_ID(type, __set_write_value_array,
-                                              att, value, size, 0);
+                                              att, value, 0, 0);
         }
     }
 
@@ -400,10 +539,19 @@ namespace PyWAttribute
         long type = att.get_data_type();
         Tango::AttrDataFormat format = att.get_data_format();
 
-        if (format == Tango::SCALAR)
+        if (format == Tango::SCALAR || format == Tango::IMAGE)
         {
+            std::string attr_type;
+            if (format == Tango::SCALAR)
+            {
+                attr_type = "scalar";
+            }
+            else
+            {
+                attr_type = "image";
+            }
             TangoSys_OMemStream o;
-            o << "Cannot call set_value(data, dim_x) on scalar attribute "
+            o << "Cannot call set_value(data, dim_x) on " << attr_type << " attribute "
               << att.get_name() << ". Use set_write_value(data) instead"
               << std::ends;
 
@@ -438,11 +586,20 @@ namespace PyWAttribute
         long type = att.get_data_type();
         Tango::AttrDataFormat format = att.get_data_format();
 
-        if (format == Tango::SCALAR)
+        if (format == Tango::SCALAR || format == Tango::SPECTRUM)
         {
+            std::string attr_type;
+            if (format == Tango::SCALAR)
+            {
+                attr_type = "scalar";
+            }
+            else
+            {
+                attr_type = "spectrum";
+            }
             TangoSys_OMemStream o;
             o << "Cannot call set_write_value(data, dim_x, dim_y) "
-              << "on scalar attribute " << att.get_name()
+              << "on " << attr_type << " attribute " << att.get_name()
               << ". Use set_write_value(data) instead" << std::ends;
 
             Tango::Except::throw_exception(
@@ -475,52 +632,6 @@ namespace PyWAttribute
 /// @name get_write_value
 /// @{ 
 
-    //
-    // PyTango 3 compatibility
-    //
-
-    template<long tangoTypeConst>
-    void __get_write_value_pytango3(Tango::WAttribute &att, boost::python::list &seq)
-    {
-        typedef typename TANGO_const2type(tangoTypeConst) TangoScalarType;
-
-        const TangoScalarType *ptr;
-
-        long length = att.get_write_value_length();
-
-        att.get_write_value(ptr);
-
-        for (long l = 0; l < length; ++l)
-        {
-            seq.append(ptr[l]);
-        }
-    }
-
-    template<>
-    void __get_write_value_pytango3<Tango::DEV_STRING>(Tango::WAttribute &att,
-                                              boost::python::list &seq)
-    {
-        const Tango::ConstDevString *ptr = NULL;
-
-        att.get_write_value(ptr);
-
-	if (ptr == NULL) {
-	    return;
-	}
-
-        long length = att.get_write_value_length();
-        for (long l = 0; l < length; ++l) {
-            seq.append(from_char_to_boost_str(ptr[l]));
-        }
-    }
-
-    inline void get_write_value_pytango3(Tango::WAttribute &att,
-                                boost::python::list &value)
-    {
-        long type = att.get_data_type();
-        TANGO_CALL_ON_ATTRIBUTE_DATA_TYPE_ID(type, __get_write_value_pytango3, att, value);
-    }
-
     template<long tangoTypeConst>
     void __get_write_value_scalar(Tango::WAttribute &att, boost::python::object* obj)
     {
@@ -731,13 +842,6 @@ void export_wattribute()
         .def("set_write_value",
             (void (*) (Tango::WAttribute &, boost::python::object &, long, long))
             &PyWAttribute::set_write_value)
-
-        // old style get_write_value
-        .def("get_write_value",
-            &PyWAttribute::get_write_value_pytango3,
-            ( arg_("self"), arg_("empty_list")))
-
-        // new style get_write_value
         .def("get_write_value",
             &PyWAttribute::get_write_value,
             ( arg_("self"), arg_("extract_as")=PyTango::ExtractAsNumpy ))
