@@ -13,7 +13,6 @@
 
 #include <Python.h>
 
-//#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 // See "Importing the API" for the why of these weird defines before
 // the inclusion of numpy. They are needed so that you can do import_array
 // in just one file while using numpy in all the project files.
@@ -34,14 +33,14 @@
     template<int N>
     struct tango_name2numpy
     {
-        enum { };
+        enum e_tango_name2numpy { };
     };
 
 #   define DEF_TANGO2NUMPY(tangoid, numpyid) \
         template<> \
         struct tango_name2numpy<tangoid> \
         { \
-            enum {value = numpyid}; \
+            enum e_tango_name2numpy {value = numpyid}; \
         }
 
     DEF_TANGO2NUMPY(Tango::DEV_STATE, NPY_UINT32 );
