@@ -14,9 +14,9 @@
 
 from functools import partial
 
-from ._tango import GreenMode
-from .device_proxy import get_device_proxy
-from .attribute_proxy import get_attribute_proxy
+from tango._tango import GreenMode
+from tango.device_proxy import get_device_proxy
+from tango.attribute_proxy import get_attribute_proxy
 
 __all__ = ("DeviceProxy", "AttributeProxy")
 
