@@ -20,10 +20,10 @@ __docformat__ = "restructuredtext"
 
 import inspect
 
-from ._tango import Except, CmdArgType, AttrDataFormat, AttrWriteType
-from ._tango import DispLevel, UserDefaultAttrProp, UserDefaultFwdAttrProp
-from ._tango import Attr, SpectrumAttr, ImageAttr, FwdAttr
-from .utils import is_non_str_seq, is_pure_str
+from tango._tango import Except, CmdArgType, AttrDataFormat, AttrWriteType
+from tango._tango import DispLevel, UserDefaultAttrProp, UserDefaultFwdAttrProp
+from tango._tango import Attr, SpectrumAttr, ImageAttr, FwdAttr
+from tango.utils import is_non_str_seq, is_pure_str
 
 
 class AttrData:
@@ -51,9 +51,11 @@ class AttrData:
             self.write_method_name = "write_" + name
             self.is_allowed_name = "is_" + name + "_allowed"
         self.attr_class = None
-        self.attr_args = []
+        self.attr_args = None
         self.att_prop = None
         self.forward = False
+        self.has_dtype_kword = False
+        self.has_size_kword = False
         if attr_info is not None:
             self.from_attr_info(attr_info)
 
@@ -69,8 +71,10 @@ class AttrData:
     def build_from_dict(self, attr_dict):
         self.forward = attr_dict.pop("forwarded", False)
         if not self.forward:
+            self.has_dtype_kword = "dtype" in attr_dict
             self.attr_type = attr_dict.pop("dtype", CmdArgType.DevDouble)
             self.attr_format = attr_dict.pop("dformat", AttrDataFormat.SCALAR)
+            self.has_size_kword = "max_dim_x" in attr_dict or "max_dim_y" in attr_dict
             self.dim_x = attr_dict.pop("max_dim_x", 1)
             self.dim_y = attr_dict.pop("max_dim_y", 0)
             self.display_level = attr_dict.pop("display_level", DispLevel.OPERATOR)
@@ -112,29 +116,24 @@ class AttrData:
                     self.is_allowed_name = fisallowed
                 elif inspect.isroutine(fisallowed):
                     self.is_allowed_name = fisallowed.__name__
-            self.attr_class = attr_dict.pop(
-                "klass", self.DftAttrClassMap[self.attr_format]
-            )
-            self.attr_args.extend((self.attr_name, self.attr_type, self.attr_write))
-            if not self.attr_format == AttrDataFormat.SCALAR:
-                self.attr_args.append(self.dim_x)
-                if not self.attr_format == AttrDataFormat.SPECTRUM:
-                    self.attr_args.append(self.dim_y)
+            self.attr_class = attr_dict.pop("klass", None)
         else:
             self.attr_class = FwdAttr
-            self.attr_args = [self.name]
+            self.attr_args = [self.attr_name]
 
-        if len(attr_dict):
-            if self.forward:
-                self.att_prop = self.__create_user_default_fwdattr_prop(attr_dict)
-            else:
-                self.att_prop = self.__create_user_default_attr_prop(attr_dict)
+        if self.forward:
+            self.att_prop = self.__create_user_default_fwdattr_prop(attr_dict)
+        elif len(attr_dict):
+            self.att_prop = self.__create_user_default_attr_prop(attr_dict)
         return self
 
     def _set_name(self, name):
         old_name = self.attr_name
         self.attr_name = name
-        self.attr_args[0] = name
+        if self.attr_args is None:
+            self.attr_args = [name]
+        else:
+            self.attr_args[0] = name
         if old_name is None:
             if self.read_method_name is None:
                 self.read_method_name = "read_" + name
@@ -149,7 +148,8 @@ class AttrData:
     def __create_user_default_fwdattr_prop(self, extra_info):
         """for internal usage only"""
         p = UserDefaultFwdAttrProp()
-        p.set_label(extra_info["label"])
+        if "label" in extra_info:
+            p.set_label(extra_info["label"])
         return p
 
     def __create_user_default_attr_prop(self, extra_info):
@@ -185,6 +185,9 @@ class AttrData:
         return p
 
     def from_attr_info(self, attr_info):
+        self.has_dtype_kword = True
+        self.has_size_kword = True
+
         name = self.class_name
         attr_name = self.attr_name
         throw_ex = self.__throw_exception
@@ -346,22 +349,37 @@ class AttrData:
                 )
             self.enum_labels = extra_info["enum_labels"]
 
-        self.attr_class = extra_info.get(
-            "klass", self.DftAttrClassMap[self.attr_format]
-        )
-        self.attr_args.extend((self.attr_name, self.attr_type, self.attr_write))
-        if not self.attr_format == AttrDataFormat.SCALAR:
-            self.attr_args.append(self.dim_x)
-            if not self.attr_format == AttrDataFormat.SPECTRUM:
-                self.attr_args.append(self.dim_y)
+        self.attr_class = extra_info.get("klass", None)
 
         att_prop = None
         if extra_info:
             att_prop = self.__create_user_default_attr_prop(extra_info)
         self.att_prop = att_prop
 
+    def set_enum_labels_to_attr_prop(self, enum_labels):
+        if self.att_prop:
+            self.att_prop.set_enum_labels(enum_labels)
+        else:
+            self.att_prop = self.__create_user_default_attr_prop(
+                {"enum_labels": enum_labels}
+            )
+
     def to_attr(self):
-        attr = self.attr_class(*self.attr_args)
+        if self.attr_args is None:
+            attr_args = [self.attr_name, self.attr_type, self.attr_write]
+            if not self.attr_format == AttrDataFormat.SCALAR:
+                attr_args.append(self.dim_x)
+                if not self.attr_format == AttrDataFormat.SPECTRUM:
+                    attr_args.append(self.dim_y)
+        else:
+            attr_args = self.attr_args
+
+        if self.attr_class is None:
+            klass = self.DftAttrClassMap[self.attr_format]
+        else:
+            klass = self.attr_class
+
+        attr = klass(*attr_args)
         if self.att_prop is not None:
             attr.set_default_properties(self.att_prop)
         attr.set_disp_level(self.display_level)
