@@ -17,7 +17,7 @@ __all__ = ("auto_monitor_init",)
 
 __docformat__ = "restructuredtext"
 
-from ._tango import AutoTangoMonitor, AutoTangoAllowThreads
+from tango._tango import AutoTangoMonitor, AutoTangoAllowThreads
 
 
 def __AutoTangoMonitor__enter__(self):
