@@ -17,7 +17,7 @@ __all__ = ("base_types_init",)
 
 __docformat__ = "restructuredtext"
 
-from ._tango import (
+from tango._tango import (
     StdStringVector,
     StdLongVector,
     StdDoubleVector,
@@ -56,9 +56,9 @@ from ._tango import (
     DispLevel,
 )
 
-from .utils import document_method, is_integer
-from .utils import document_enum as __document_enum
-from .utils import seq_2_StdStringVector, StdStringVector_2_seq
+from tango.utils import document_method, is_integer
+from tango.utils import document_enum as __document_enum
+from tango.utils import seq_2_StdStringVector, StdStringVector_2_seq
 
 
 def __StdVector__add(self, seq):
@@ -436,7 +436,6 @@ def __doc_base_types():
         - DevULong64
         - DevVarLong64Array
         - DevVarULong64Array
-        - DevInt
         - DevEncoded
         - DevEnum
         - DevPipeBlob
