@@ -13,11 +13,11 @@
 This is an internal PyTango module.
 """
 
-__all__ = ["callback_init"]
+__all__ = ("callback_init",)
 
 __docformat__ = "restructuredtext"
 
-from ._tango import CmdDoneEvent, AttrReadEvent, AttrWrittenEvent
+from tango._tango import CmdDoneEvent, AttrReadEvent, AttrWrittenEvent
 
 
 def __init_Callback():
