@@ -199,7 +199,7 @@ class Object:
         try:
             r = self._helper.get(name)
         except KeyError as ke:
-            raise AttributeError(f'Unknown {name}') from ke
+            raise AttributeError(f"Unknown {name}") from ke
         if isinstance(r, tango.CommandInfo):
             self.__dict__[name] = r.func
             return r.func
@@ -209,7 +209,7 @@ class Object:
         try:
             return self._helper.set(name, value)
         except KeyError as ke:
-            raise AttributeError(f'Unknown {name}') from ke
+            raise AttributeError(f"Unknown {name}") from ke
 
     def __getitem__(self, name):
         return self._helper[name]
