@@ -20,7 +20,7 @@ __docformat__ = "restructuredtext"
 
 import collections.abc
 
-from ._tango import (
+from tango._tango import (
     Connection,
     DeviceData,
     __CallBackAutoDie,
@@ -29,9 +29,9 @@ from ._tango import (
     Database,
     ExtractAs,
 )
-from .utils import document_method as __document_method
-from .utils import document_static_method as __document_static_method
-from .green import green
+from tango.utils import document_method as __document_method
+from tango.utils import document_static_method as __document_static_method
+from tango.green import green
 
 
 def __CallBackAutoDie__cmd_ended_aux(self, fn):
