@@ -19,7 +19,7 @@ __docformat__ = "restructuredtext"
 
 import collections.abc
 
-from ._tango import (
+from tango._tango import (
     StdStringVector,
     Database,
     DbDatum,
@@ -34,7 +34,7 @@ from ._tango import (
     DbServerData,
 )
 
-from .utils import (
+from tango.utils import (
     is_pure_str,
     is_non_str_seq,
     seq_2_StdStringVector,
@@ -45,7 +45,7 @@ from .utils import (
     obj_2_property,
     ensure_binary,
 )
-from .utils import document_method as __document_method
+from tango.utils import document_method as __document_method
 
 
 # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
@@ -1822,7 +1822,7 @@ def __doc_Database():
         """
     delete_server_info(self, server) -> None
 
-            Delete server information of the specifed server from the database.
+            Delete server information of the specified server from the database.
 
         Parameters :
             - server : (str) name of the server to be deleted with
@@ -1897,10 +1897,10 @@ def __doc_Database():
 
             Return the list of all servers registered in the database.
             If wildcard parameter is given, then the list of matching servers
-            will be returned (ex: Serial/*)
+            will be returned (ex: Serial/\\*)
 
         Parameters :
-            - wildcard : (str) host wildcard (ex: Serial/*)
+            - wildcard : (str) host wildcard (ex: Serial/\\*)
         Return     : DbDatum containing list of registered servers
     """,
     )
