@@ -19,8 +19,8 @@ __docformat__ = "restructuredtext"
 
 import copy
 
-from .utils import document_method as __document_method
-from ._tango import DeviceAttribute, ExtractAs
+from tango.utils import document_method as __document_method
+from tango._tango import DeviceAttribute, ExtractAs
 
 
 def __DeviceAttribute__get_data(self):
