@@ -20,7 +20,7 @@ __docformat__ = "restructuredtext"
 
 import collections.abc
 
-from ._tango import (
+from tango._tango import (
     Except,
     DevFailed,
     DeviceClass,
@@ -28,14 +28,14 @@ from ._tango import (
     DispLevel,
     UserDefaultAttrProp,
 )
-from .pyutil import Util
+from tango.pyutil import Util
 
-from .utils import is_pure_str, is_non_str_seq, seqStr_2_obj, obj_2_str, is_array
-from .utils import document_method as __document_method
+from tango.utils import is_pure_str, is_non_str_seq, seqStr_2_obj, obj_2_str, is_array
+from tango.utils import document_method as __document_method
 
-from .globals import get_class, get_class_by_class, get_constructed_class_by_class
-from .attr_data import AttrData
-from .pipe_data import PipeData
+from tango.globals import get_class, get_class_by_class, get_constructed_class_by_class
+from tango.attr_data import AttrData
+from tango.pipe_data import PipeData
 
 
 class PropUtil:
@@ -44,7 +44,6 @@ class PropUtil:
     scalar_int_types = (
         CmdArgType.DevShort,
         CmdArgType.DevUShort,
-        CmdArgType.DevInt,
         CmdArgType.DevLong,
         CmdArgType.DevULong,
     )
@@ -366,7 +365,9 @@ def __DeviceClass__attribute_factory(self, attr_list):
         else:
             attr_data = AttrData(attr_name, self.get_name(), attr_info)
         if attr_data.forward:
-            self._create_fwd_attribute(attr_list, attr_data.name, attr_data.att_prop)
+            self._create_fwd_attribute(
+                attr_list, attr_data.attr_name, attr_data.att_prop
+            )
         else:
             self._create_attribute(
                 attr_list,
@@ -1010,26 +1011,32 @@ def __doc_DeviceClass():
     document_method(
         "add_wiz_dev_prop",
         """
-    add_wiz_dev_prop(self, str, str) -> None
-    add_wiz_dev_prop(self, str, str, str) -> None
+    add_wiz_dev_prop(self, name, desc) -> None
+    add_wiz_dev_prop(self, name, desc, def) -> None
 
             For internal usage only
 
-        Parameters : None
-        Return     : None
+        :param str name: device property name
+        :param str desc: device property description
+        :param str def: device property default value
+
+        :return: None
     """,
     )
 
     document_method(
         "add_wiz_class_prop",
         """
-    add_wiz_class_prop(self, str, str) -> None
-    add_wiz_class_prop(self, str, str, str) -> None
+    add_wiz_class_prop(self, name, desc) -> None
+    add_wiz_class_prop(self, name, desc, def) -> None
 
             For internal usage only
 
-        Parameters : None
-        Return     : None
+        :param str name: class property name
+        :param str desc: class property description
+        :param str def: class property default value
+
+        :return: None
     """,
     )
 
