@@ -17,8 +17,8 @@ __all__ = ("device_data_init",)
 
 __docformat__ = "restructuredtext"
 
-from .utils import document_method as __document_method
-from ._tango import DeviceData
+from tango.utils import document_method as __document_method
+from tango._tango import DeviceData
 
 
 def __DeviceData__get_data(self):
