@@ -17,7 +17,7 @@ from functools import wraps
 from threading import get_ident
 
 # Tango imports
-from ._tango import GreenMode
+from tango._tango import GreenMode
 
 __all__ = (
     "get_green_mode",
@@ -26,8 +26,17 @@ __all__ = (
     "green_callback",
     "get_executor",
     "get_object_executor",
+    "switch_existing_global_executors_to_thread",
 )
 
+try:
+    import gevent
+
+    del gevent
+    _gevent_available = True
+except ImportError:
+    _gevent_available = False
+
 # Handle current green mode
 
 try:
@@ -72,10 +81,13 @@ class AbstractExecutor:
     default_wait = NotImplemented
 
     def __init__(self):
-        self.thread_id = get_ident()
+        self.ident = get_ident(), os.getpid()
+
+    def get_ident(self):
+        return self.ident
 
     def in_executor_context(self):
-        return self.thread_id == get_ident()
+        return self.ident == (get_ident(), os.getpid())
 
     def delegate(self, fn, *args, **kwargs):
         """Delegate an operation and return an accessor."""
@@ -148,21 +160,39 @@ def get_executor(green_mode=None):
     if green_mode == GreenMode.Synchronous:
         return get_synchronous_executor()
     if green_mode == GreenMode.Gevent:
-        from . import gevent_executor
+        from tango import gevent_executor
 
         return gevent_executor.get_global_executor()
     if green_mode == GreenMode.Futures:
-        from . import futures_executor
+        from tango import futures_executor
 
         return futures_executor.get_global_executor()
     if green_mode == GreenMode.Asyncio:
-        from . import asyncio_executor
+        from tango import asyncio_executor
 
         return asyncio_executor.get_global_executor()
     # Invalid green mode
     raise TypeError("Not a valid green mode")
 
 
+def switch_existing_global_executors_to_thread():
+    """
+    checks which global executor existing, and if they are belong to the caller thread
+    if not - creates a new executor, linked to thread, and set it as global
+    """
+    from tango import asyncio_executor
+    from tango import futures_executor
+
+    if _gevent_available:
+        from tango import gevent_executor
+    else:
+        gevent_executor = None
+
+    for executor in [asyncio_executor, futures_executor, gevent_executor]:
+        if executor:
+            executor._switch_global_executor_to_thread()
+
+
 def get_object_executor(obj, green_mode=None):
     """Returns the proper executor for the given object.
 
