@@ -19,10 +19,11 @@ __docformat__ = "restructuredtext"
 
 import collections.abc
 
-from ._tango import __Group as _RealGroup, StdStringVector
-from .utils import seq_2_StdStringVector, is_pure_str
-from .utils import document_method as __document_method
-from .device_proxy import __init_device_proxy_internals as init_device_proxy
+from tango._tango import __Group as _RealGroup
+from tango.utils import seq_2_StdStringVector, is_non_str_seq, is_pure_str
+from tango.utils import document_method as __document_method
+from tango.utils import _get_device_fqtrl_if_necessary
+from tango.device_proxy import __init_device_proxy_internals as init_device_proxy
 
 
 def _apply_to(fn, key):
@@ -75,18 +76,25 @@ class Group:
 
     def _add(self, patterns_or_group, timeout_ms=-1):
         if isinstance(patterns_or_group, _RealGroup):
-            return self.__group._add(patterns_or_group, timeout_ms)
-        elif isinstance(patterns_or_group, StdStringVector):
-            return self.__group._add(patterns_or_group, timeout_ms)
-        elif isinstance(patterns_or_group, str):
-            return self.__group._add(patterns_or_group, timeout_ms)
-        elif isinstance(patterns_or_group, collections.abc.Sequence):
-            patterns = seq_2_StdStringVector(patterns_or_group)
-            return self.__group._add(patterns, timeout_ms)
+            items = patterns_or_group
         else:
-            raise TypeError(
-                "Parameter patterns_or_group: Should be Group, str or a sequence of strings."
-            )
+            if is_pure_str(patterns_or_group):
+                items = [patterns_or_group]
+            elif is_non_str_seq(patterns_or_group):
+                items = patterns_or_group
+            else:
+                raise TypeError(
+                    "Parameter patterns_or_group: Should be Group, "
+                    "str or a sequence of strings."
+                )
+
+            # If TestContext active, each short TRL is replaced with a fully-qualified
+            # TRL, using test server's connection details.  Otherwise, left as-is.
+            items = [_get_device_fqtrl_if_necessary(item) for item in items]
+            items = seq_2_StdStringVector(items)
+
+        resp = self.__group._add(items, timeout_ms)
+        return resp
 
     def remove(self, patterns, forward=True):
         if isinstance(patterns, str):
@@ -122,6 +130,9 @@ class Group:
     def __len__(self):
         return self.get_size()
 
+    def __repr__(self):
+        return "Group(%s)" % self.get_name()
+
     def command_inout(self, cmd_name, param=None, forward=True):
         if param is None:
             idx = self.command_inout_asynch(cmd_name, forget=False, forward=forward)
