@@ -11,17 +11,16 @@
 
 __all__ = ("PipeConfig",)
 
-from ._tango import (
+from tango._tango import (
     Pipe,
     PipeWriteType,
     UserDefaultPipeProp,
     CmdArgType,
     DevState,
     DispLevel,
-    constants,
 )
 
-from .utils import (
+from tango.utils import (
     scalar_to_array_type,
     TO_TANGO_TYPE,
     is_non_str_seq,
@@ -29,7 +28,7 @@ from .utils import (
     is_integer,
     is_number,
 )
-from .utils import document_method as __document_method
+from tango.utils import document_method as __document_method
 
 
 class PipeConfig:
@@ -72,21 +71,6 @@ def __get_pipe_type_simple(obj):
     return tg_type
 
 
-def __get_pipe_type_numpy_support(obj):
-    try:
-        ndim, dtype = obj.ndim, str(obj.dtype)
-    except AttributeError:
-        return __get_pipe_type_simple(obj)
-    if ndim > 1:
-        raise TypeError(
-            f"cannot translate numpy array with {obj.ndim} " f"dimensions to tango type"
-        )
-    tg_type = TO_TANGO_TYPE[dtype]
-    if ndim > 0:
-        tg_type = scalar_to_array_type(dtype)
-    return tg_type
-
-
 def __get_tango_type(dtype):
     if is_non_str_seq(dtype):
         tg_type = dtype[0]
@@ -102,9 +86,18 @@ def __get_tango_type(dtype):
 def __get_pipe_type(obj, dtype=None):
     if dtype is not None:
         return __get_tango_type(dtype)
-    if constants.NUMPY_SUPPORT:
-        return __get_pipe_type_numpy_support(obj)
-    return __get_pipe_type_simple(obj)
+    try:
+        ndim, dtype = obj.ndim, str(obj.dtype)
+    except AttributeError:
+        return __get_pipe_type_simple(obj)
+    if ndim > 1:
+        raise TypeError(
+            f"cannot translate numpy array with {obj.ndim} " f"dimensions to tango type"
+        )
+    tg_type = TO_TANGO_TYPE[dtype]
+    if ndim > 0:
+        tg_type = scalar_to_array_type(dtype)
+    return tg_type
 
 
 def __sanatize_pipe_element(elem):
