@@ -20,8 +20,8 @@ __docformat__ = "restructuredtext"
 
 import inspect
 
-from ._tango import Except, DispLevel, Pipe, PipeWriteType, UserDefaultPipeProp
-from .utils import is_non_str_seq, is_pure_str
+from tango._tango import Except, DispLevel, Pipe, PipeWriteType, UserDefaultPipeProp
+from tango.utils import is_non_str_seq, is_pure_str
 
 
 class PipeData:
