@@ -17,7 +17,7 @@ __all__ = ("pytango_pprint_init",)
 
 __docformat__ = "restructuredtext"
 
-from ._tango import (
+from tango._tango import (
     StdStringVector,
     StdLongVector,
     CommandInfoList,
@@ -69,10 +69,10 @@ from ._tango import (
     CmdArgType,
 )
 
-from .device_server import AttributeAlarm, EventProperties
-from .device_server import ChangeEventProp, PeriodicEventProp, ArchiveEventProp
-from .device_server import AttributeConfig, AttributeConfig_2
-from .device_server import AttributeConfig_3, AttributeConfig_5
+from tango.device_server import AttributeAlarm, EventProperties
+from tango.device_server import ChangeEventProp, PeriodicEventProp, ArchiveEventProp
+from tango.device_server import AttributeConfig, AttributeConfig_2
+from tango.device_server import AttributeConfig_3, AttributeConfig_5
 import collections.abc
 
 
