@@ -46,13 +46,13 @@ class Release:
     """
 
     name = "pytango"
-    version_info = (9, 4, 2)
+    version_info = (9, 5, 0)
     version = ".".join(map(str, version_info[:3]))
     release = "".join(map(str, version_info[3:]))
     separator = "." if "dev" in release or "post" in release else ""
     version_long = version + separator + release
 
-    version_description = "This version implements the C++ Tango 9.4 API."
+    version_description = "This version implements the C++ Tango 9.5 API."
     version_number = int(version.replace(".", ""))
     description = "A python binding for the Tango control system"
     long_description = "This module implements the Python Tango Device API mapping."
@@ -61,5 +61,5 @@ class Release:
     author_lines = "\n".join([f"{x[0]} <{x[1]}>" for x in authors.values()])
     url = "http://gitlab.com/tango-controls/pytango"
     download_url = "http://pypi.python.org/pypi/pytango"
-    platform = ["Linux", "Windows XP/Vista/7/8/10"]
+    platform = ["Linux", "Windows", "macOS"]
     keywords = ["Tango", "CORBA", "binding"]
