@@ -23,26 +23,32 @@ import asyncio
 import warnings
 import threading
 
-from ._tango import AttrDataFormat, AttrWriteType, CmdArgType, PipeWriteType
-from ._tango import DevFailed, GreenMode, SerialModel, ApiUtil
+from tango._tango import AttrDataFormat, AttrWriteType, PipeWriteType
+from tango._tango import DevFailed, GreenMode, SerialModel, ApiUtil
 
-from .attr_data import AttrData
-from .pipe_data import PipeData
-from .device_class import DeviceClass
-from .device_server import LatestDeviceImpl, get_worker, set_worker, run_in_executor
-from .utils import get_enum_labels
-from .utils import (
+from tango.utils import PyTangoUserWarning
+from tango.attr_data import AttrData
+from tango.pipe_data import PipeData
+from tango.device_class import DeviceClass
+from tango.device_server import (
+    LatestDeviceImpl,
+    get_worker,
+    set_worker,
+    run_in_executor,
+)
+from tango.utils import (
     is_seq,
     is_non_str_seq,
     is_pure_str,
-    is_enum_seq,
-    is_enum,
+    get_tango_type_format,
+    get_attribute_type_format,
     set_complex_value,
+    parse_type_hint,
 )
-from .utils import is_devstate, is_devstate_seq, scalar_to_array_type, TO_TANGO_TYPE
-from .green import get_green_mode, get_executor
-from .asyncio_executor import AsyncioExecutor
-from .pyutil import Util
+from tango.utils import scalar_to_array_type
+from tango.green import get_green_mode, get_executor
+from tango.pyutil import Util
+from tango.asyncio_executor import AsyncioExecutor
 
 __all__ = (
     "DeviceMeta",
@@ -62,6 +68,23 @@ API_VERSION = 2
 
 # Helpers
 
+_debug_run_active = False
+try:
+    import pydevd
+
+    _debugger = pydevd.get_global_debugger()
+    _disabled_via_env_var = ApiUtil.get_env_var("PYTANGO_DISABLE_DEBUG_TRACE_PATCHING")
+    if _debugger is not None and not _disabled_via_env_var:
+        _debug_run_active = True
+        warnings.warn(
+            "pydevd debugger detected: tango.server.Device methods "
+            "will be patched for tracing.",
+            category=PyTangoUserWarning,
+        )
+except Exception:
+    pass
+
+
 _coverage_run_active = False
 
 try:
@@ -71,64 +94,59 @@ try:
         if ApiUtil.get_env_var("PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING"):
             warnings.warn(
                 "Coverage run detected, but PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING "
-                "environment variable is set. Reported coverage may be inaccurate."
+                "environment variable is set. Reported coverage may be inaccurate.",
+                category=PyTangoUserWarning,
+            )
+        elif _debug_run_active:
+            warnings.warn(
+                "Coverage run detected, but debugger also detected. "
+                "Patching only for debugger, not for coverage."
+                "Reported coverage may be inaccurate.",
+                category=PyTangoUserWarning,
             )
         else:
             if getattr(threading, "_trace_hook", None):
                 _coverage_run_active = True
                 warnings.warn(
                     "Coverage run detected: tango.server.Device methods "
-                    "will be patched for tracing."
+                    "will be patched for tracing.",
+                    category=PyTangoUserWarning,
                 )
             else:
                 warnings.warn(
                     "Coverage run detected, but unable to get threading._trace_hook. "
-                    "Reported coverage may be inaccurate."
+                    "Reported coverage may be inaccurate.",
+                    category=PyTangoUserWarning,
                 )
 
 except Exception:
     pass
 
 
-def _force_threading_trace_hook(fn):
+_force_tracing = _debug_run_active or _coverage_run_active
+
+
+def _forcefully_traced_method(fn):
     @functools.wraps(fn)
     def trace_wrapper(*args, **kwargs):
-        original_tracer = sys.gettrace()
-
-        threading_trace_hook = getattr(threading, "_trace_hook", None)
-        if threading_trace_hook:
-            sys.settrace(threading_trace_hook)
+        original_tracer = "EMPTY"
+        if _debug_run_active:
+            pydevd.settrace(suspend=False, trace_only_current_thread=True)
+        elif _coverage_run_active:
+            original_tracer = sys.gettrace()
+            threading_trace_hook = getattr(threading, "_trace_hook", None)
+            if threading_trace_hook:
+                sys.settrace(threading_trace_hook)
         try:
             ret = fn(*args, **kwargs)
         finally:
-            sys.settrace(original_tracer)
+            if original_tracer != "EMPTY":
+                sys.settrace(original_tracer)
         return ret
 
     return trace_wrapper
 
 
-def _get_tango_type_format(dtype=None, dformat=None, caller=None):
-    if dformat is None:
-        dformat = AttrDataFormat.SCALAR
-        if is_non_str_seq(dtype):
-            if len(dtype):
-                dtype = dtype[0]
-                dformat = AttrDataFormat.SPECTRUM
-                if is_non_str_seq(dtype):
-                    if len(dtype):
-                        dtype = dtype[0]
-                        dformat = AttrDataFormat.IMAGE
-                    elif caller == "attribute":
-                        raise TypeError(
-                            "Image attribute type must be specified as ((<dtype>,),)"
-                        )
-            elif caller == "attribute":
-                raise TypeError(
-                    "Spectrum attribute type must be specified as (<dtype>,)"
-                )
-    return TO_TANGO_TYPE[dtype], dformat
-
-
 def from_typeformat_to_type(dtype, dformat):
     if dformat == AttrDataFormat.SCALAR:
         return dtype
@@ -151,8 +169,8 @@ def __get_wrapped_read_method(attribute, read_method):
     if already_wrapped:
         return read_method
 
-    if _coverage_run_active:
-        read_method = _force_threading_trace_hook(read_method)
+    if _force_tracing:
+        read_method = _forcefully_traced_method(read_method)
 
     if attribute.read_green_mode:
 
@@ -207,8 +225,8 @@ def __get_wrapped_write_method(attribute, write_method):
     if already_wrapped:
         return write_method
 
-    if _coverage_run_active:
-        write_method = _force_threading_trace_hook(write_method)
+    if _force_tracing:
+        write_method = _forcefully_traced_method(write_method)
 
     if attribute.write_green_mode:
 
@@ -263,8 +281,8 @@ def __get_wrapped_isallowed_method(attribute, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
-    if _coverage_run_active:
-        isallowed_method = _force_threading_trace_hook(isallowed_method)
+    if _force_tracing:
+        isallowed_method = _forcefully_traced_method(isallowed_method)
 
     if attribute.isallowed_green_mode:
 
@@ -320,19 +338,64 @@ def __patch_attr_methods(tango_device_klass, attribute):
     """
     if attribute.attr_write in (AttrWriteType.READ, AttrWriteType.READ_WRITE):
         __patch_read_method(tango_device_klass, attribute)
+
     if attribute.attr_write in (AttrWriteType.WRITE, AttrWriteType.READ_WRITE):
         __patch_write_method(tango_device_klass, attribute)
 
     __patch_isallowed_method(tango_device_klass, attribute)
 
 
+def __get_attribute_type_from_hint(attribute, type_hint=None, device_klass=None):
+    if not attribute.has_dtype_kword:
+        if not type_hint:
+            if attribute.attr_write in (AttrWriteType.READ, AttrWriteType.READ_WRITE):
+                read_method = getattr(device_klass, attribute.read_method_name)
+                type_hint = dict(read_method.__annotations__).get("return", None)
+            if not type_hint and attribute.attr_write in (
+                AttrWriteType.WRITE,
+                AttrWriteType.READ_WRITE,
+            ):
+                write_method = getattr(device_klass, attribute.write_method_name)
+                type_hints = dict(write_method.__annotations__)
+                type_hints.pop("return", None)
+                if type_hints:
+                    type_hint = list(type_hints.values())[-1]
+
+        if type_hint:
+            dtype, dformat, max_x, max_y = parse_type_hint(
+                type_hint, caller="attribute"
+            )
+            if dformat is None:
+                if attribute.attr_format not in [
+                    AttrDataFormat.IMAGE,
+                    AttrDataFormat.SPECTRUM,
+                ]:
+                    raise RuntimeError(
+                        "For numpy.ndarrays AttrDataFormat has to be specified"
+                    )
+                dformat = attribute.attr_format
+
+            dtype, dformat, enum_labels = get_attribute_type_format(
+                dtype, dformat, None
+            )
+            attribute.attr_type = dtype
+            attribute.attr_format = dformat
+            if enum_labels:
+                attribute.set_enum_labels_to_attr_prop(enum_labels)
+            if not attribute.has_size_kword:
+                if max_x:
+                    attribute.dim_x = max_x
+                if max_y:
+                    attribute.dim_y = max_y
+
+
 def __get_wrapped_pipe_read_method(pipe, read_method):
     already_wrapped = hasattr(read_method, "__access_wrapped__")
     if already_wrapped:
         return read_method
 
-    if _coverage_run_active:
-        read_method = _force_threading_trace_hook(read_method)
+    if _force_tracing:
+        read_method = _forcefully_traced_method(read_method)
 
     if pipe.read_green_mode:
 
@@ -385,8 +448,8 @@ def __get_wrapped_pipe_write_method(pipe, write_method):
     if already_wrapped:
         return write_method
 
-    if _coverage_run_active:
-        write_method = _force_threading_trace_hook(write_method)
+    if _force_tracing:
+        write_method = _forcefully_traced_method(write_method)
 
     if pipe.write_green_mode:
 
@@ -441,8 +504,8 @@ def __get_wrapped_pipe_isallowed_method(pipe, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
-    if _coverage_run_active:
-        isallowed_method = _force_threading_trace_hook(isallowed_method)
+    if _force_tracing:
+        isallowed_method = _forcefully_traced_method(isallowed_method)
 
     if pipe.isallowed_green_mode:
 
@@ -502,6 +565,12 @@ def __patch_pipe_methods(tango_device_klass, pipe):
     __patch_pipe_isallowed_method(tango_device_klass, pipe)
 
 
+def __get_property_type_from_hint(property, type_hint):
+    if property.dtype is None:
+        dtype, _, _, _ = parse_type_hint(type_hint, caller="property")
+        property.dtype = from_typeformat_to_type(*get_tango_type_format(dtype))
+
+
 def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd_name):
     """
     :param tango_device_klass: a DeviceImpl class
@@ -515,8 +584,8 @@ def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd
     if already_wrapped:
         return is_allowed_method.__wrapped_method_name__
 
-    if _coverage_run_active:
-        is_allowed_method = _force_threading_trace_hook(is_allowed_method)
+    if _force_tracing:
+        is_allowed_method = _forcefully_traced_method(is_allowed_method)
 
     method_name = getattr(is_allowed_method, "__name__", f"is_{cmd_name}_allowed")
     method_name = f"__wrapped_{method_name}__"
@@ -529,17 +598,50 @@ def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd
     return method_name
 
 
+def __unwrap_method(method):
+    while hasattr(method, "__wrapped__"):
+        method = method.__wrapped__
+
+    return method
+
+
+def __warn_if_any_standard_device_method_should_be_coroutine(klass):
+    worker = get_worker()
+    # get base device class:
+    if isinstance(worker, AsyncioExecutor):
+        for parent in klass.__bases__:
+            if type(parent) == DeviceMeta:
+                for method in (
+                    "init_device",
+                    "delete_device",
+                    "dev_state",
+                    "dev_status",
+                    "read_attr_hardware",
+                    "always_executed_hook",
+                ):
+                    user_method = __unwrap_method(getattr(klass, method))
+                    base_method = __unwrap_method(getattr(parent, method))
+                    if user_method != base_method and not asyncio.iscoroutinefunction(
+                        user_method
+                    ):
+                        warnings.warn(
+                            f"Note: {method} function in Asyncio device should be coroutine!",
+                            category=PyTangoUserWarning,
+                        )
+
+
 def __patch_standard_device_methods(klass):
     # TODO allow to force non green mode
 
     init_device_orig = klass.init_device
     already_wrapped = hasattr(init_device_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _coverage_run_active:
-            init_device_orig = _force_threading_trace_hook(init_device_orig)
+        if _force_tracing:
+            init_device_orig = _forcefully_traced_method(init_device_orig)
 
         @functools.wraps(init_device_orig)
         def init_device(self):
+            __warn_if_any_standard_device_method_should_be_coroutine(klass)
             return get_worker().execute(init_device_orig, self)
 
         init_device.__access_wrapped__ = True
@@ -548,8 +650,8 @@ def __patch_standard_device_methods(klass):
     delete_device_orig = klass.delete_device
     already_wrapped = hasattr(delete_device_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _coverage_run_active:
-            delete_device_orig = _force_threading_trace_hook(delete_device_orig)
+        if _force_tracing:
+            delete_device_orig = _forcefully_traced_method(delete_device_orig)
 
         @functools.wraps(delete_device_orig)
         def delete_device(self):
@@ -563,9 +665,9 @@ def __patch_standard_device_methods(klass):
     if not already_wrapped:
         dev_state_async = klass._BaseDevice__asyncio_dev_state
         is_base_klass_state = dev_state_orig == BaseDevice.dev_state
-        if _coverage_run_active:
-            dev_state_orig = _force_threading_trace_hook(dev_state_orig)
-            dev_state_async = _force_threading_trace_hook(dev_state_async)
+        if _force_tracing:
+            dev_state_orig = _forcefully_traced_method(dev_state_orig)
+            dev_state_async = _forcefully_traced_method(dev_state_async)
 
         @functools.wraps(dev_state_orig)
         def dev_state(self):
@@ -580,8 +682,8 @@ def __patch_standard_device_methods(klass):
     dev_status_orig = klass.dev_status
     already_wrapped = hasattr(dev_status_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _coverage_run_active:
-            dev_status_orig = _force_threading_trace_hook(dev_status_orig)
+        if _force_tracing:
+            dev_status_orig = _forcefully_traced_method(dev_status_orig)
 
         @functools.wraps(dev_status_orig)
         def dev_status(self):
@@ -593,10 +695,8 @@ def __patch_standard_device_methods(klass):
     read_attr_hardware_orig = klass.read_attr_hardware
     already_wrapped = hasattr(read_attr_hardware_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _coverage_run_active:
-            read_attr_hardware_orig = _force_threading_trace_hook(
-                read_attr_hardware_orig
-            )
+        if _force_tracing:
+            read_attr_hardware_orig = _forcefully_traced_method(read_attr_hardware_orig)
 
         @functools.wraps(read_attr_hardware_orig)
         def read_attr_hardware(self, attr_list):
@@ -608,8 +708,8 @@ def __patch_standard_device_methods(klass):
     always_executed_hook_orig = klass.always_executed_hook
     already_wrapped = hasattr(always_executed_hook_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _coverage_run_active:
-            always_executed_hook_orig = _force_threading_trace_hook(
+        if _force_tracing:
+            always_executed_hook_orig = _forcefully_traced_method(
                 always_executed_hook_orig
             )
 
@@ -637,9 +737,9 @@ class _DeviceClass(DeviceClass):
         DeviceClass.__init__(self, name)
         self.set_type(name)
 
-        if _coverage_run_active:
+        if _force_tracing:
             orig_dyn_attr = getattr(self, "dyn_attr")
-            setattr(self, "dyn_attr", _force_threading_trace_hook(orig_dyn_attr))
+            setattr(self, "dyn_attr", _forcefully_traced_method(orig_dyn_attr))
 
     def dyn_attr(self, dev_list):
         """Invoked to create dynamic attributes for the given devices.
@@ -669,6 +769,10 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
     if attrs is None:
         attrs = tango_device_klass.__dict__
 
+    klass_annotations = {}
+    if hasattr(tango_device_klass, "__annotations__"):
+        klass_annotations = dict(tango_device_klass.__annotations__)
+
     attr_list = {}
     pipe_list = {}
     class_property_list = {}
@@ -677,6 +781,7 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
 
     for attr_name, attr_obj in attrs.items():
         if isinstance(attr_obj, attribute):
+            klass_attribute_name = attr_name
             if attr_obj.attr_name is None:
                 attr_obj._set_name(attr_name)
             else:
@@ -684,6 +789,15 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
             attr_list[attr_name] = attr_obj
             if not attr_obj.forward:
                 __patch_attr_methods(tango_device_klass, attr_obj)
+                if klass_attribute_name in klass_annotations:
+                    __get_attribute_type_from_hint(
+                        attr_obj, type_hint=klass_annotations[klass_attribute_name]
+                    )
+                else:
+                    __get_attribute_type_from_hint(
+                        attr_obj, device_klass=tango_device_klass
+                    )
+
         elif isinstance(attr_obj, pipe):
             if attr_obj.pipe_name is None:
                 attr_obj._set_name(attr_name)
@@ -691,7 +805,10 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
                 attr_name = attr_obj.pipe_name
             pipe_list[attr_name] = attr_obj
             __patch_pipe_methods(tango_device_klass, attr_obj)
+
         elif isinstance(attr_obj, device_property):
+            if attr_name in klass_annotations:
+                __get_property_type_from_hint(attr_obj, klass_annotations[attr_name])
             attr_obj.name = attr_name
             # if you modify the attr_obj order then you should
             # take care of the code in get_device_properties()
@@ -701,13 +818,17 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
                 attr_obj.default_value,
                 attr_obj.mandatory,
             ]
+
         elif isinstance(attr_obj, class_property):
+            if attr_name in klass_annotations:
+                __get_property_type_from_hint(attr_obj, klass_annotations[attr_name])
             attr_obj.name = attr_name
             class_property_list[attr_name] = [
                 attr_obj.dtype,
                 attr_obj.doc,
                 attr_obj.default_value,
             ]
+
         elif inspect.isroutine(attr_obj):
             if hasattr(attr_obj, "__tango_command__"):
                 cmd_name, cmd_info = attr_obj.__tango_command__
@@ -842,7 +963,8 @@ class BaseDevice(LatestDeviceImpl):
             return await asyncio.to_thread(LatestDeviceImpl.dev_state, self)
         else:
             warnings.warn(
-                "DevState.ALARM cannot be correctly reported with GreenMode.Asyncio prior to Python 3.9"
+                "DevState.ALARM cannot be correctly reported with GreenMode.Asyncio prior to Python 3.9",
+                category=PyTangoUserWarning,
             )
             # See https://gitlab.com/tango-controls/pytango/-/merge_requests/564 for details
             return LatestDeviceImpl.dev_state(self)
@@ -965,8 +1087,8 @@ class attribute(AttrData):
     max_dim_y              :obj:`int`                       0                                       maximum size for y dimension (ignored for SCALAR and SPECTRUM formats)
     display_level          :obj:`~tango.DispLevel`          :obj:`~tango.DisLevel.OPERATOR`         display level
     polling_period         :obj:`int`                       -1                                      polling period
-    memorized              :obj:`bool`                      False                                   attribute should or not be memorized
-    hw_memorized           :obj:`bool`                      False                                   write method should be called at startup when restoring memorize value (dangerous!)
+    memorized              :obj:`bool`                      False                                   attribute must be memorized (only applicable to scalar, writeable attributes).  If True, the latest write value, i.e., set point, is stored in the Tango database - see also ``hw_memorized`` parameter.  Corresponds to low-level :meth:`tango.Attr.set_memorized`.
+    hw_memorized           :obj:`bool`                      False                                   memorized value will be restored by automatically calling attribute write method at startup, and after each ``Init`` command call (only applies if ``memorized`` is set to True).  Corresponds to low-level :meth:`tango.Attr.set_memorized_init`
     access                 :obj:`~tango.AttrWriteType`      :obj:`~tango.AttrWriteType.READ`        read only/ read write / write only access
     fget (or fread)        :obj:`str` or :obj:`callable`    'read_<attr_name>'                      read method name or method object
     fset (or fwrite)       :obj:`str` or :obj:`callable`    'write_<attr_name>'                     write method name or method object
@@ -1052,9 +1174,14 @@ class attribute(AttrData):
         class_name = kwargs.pop("class_name", None)
         forward = kwargs.get("forwarded", False)
         if forward:
-            expected = 2 if "label" in kwargs else 1
-            if len(kwargs) > expected:
-                raise TypeError("Forwarded attributes only support label argument")
+            kwarg_copy = dict(kwargs)
+            for k in ["name", "label", "forwarded"]:
+                if k in kwarg_copy:
+                    del kwarg_copy[k]
+            if len(kwarg_copy):
+                raise TypeError(
+                    "Forwarded attributes only support 'label' and 'name' arguments"
+                )
         else:
             green_mode = kwargs.pop("green_mode", True)
             self.read_green_mode = kwargs.pop("read_green_mode", green_mode)
@@ -1089,33 +1216,12 @@ class attribute(AttrData):
         if "dtype" in kwargs:
             dtype = kwargs["dtype"]
             dformat = kwargs.get("dformat")
-            if is_enum(dtype) or is_enum_seq(dtype):
-                enum_labels = kwargs.get("enum_labels")
-                if enum_labels:
-                    raise TypeError(
-                        "For dtype of enum.Enum, (enum.Enum,) or ((enum.Enum,),) the enum_labels must not "
-                        f"be specified - dtype: {dtype}, enum_labels: {enum_labels}."
-                    )
-                _dtype = dtype
-                dtype = CmdArgType.DevEnum
-
-                while is_enum_seq(_dtype):
-                    _dtype = _dtype[0]
-                    dtype = (dtype,)
-
-                kwargs["enum_labels"] = get_enum_labels(_dtype)
-
-            elif is_devstate(dtype) or is_devstate_seq(dtype):
-                _dtype = dtype
-                dtype = CmdArgType.DevState
-
-                while is_devstate_seq(_dtype):
-                    _dtype = _dtype[0]
-                    dtype = (dtype,)
-
-            kwargs["dtype"], kwargs["dformat"] = _get_tango_type_format(
-                dtype, dformat, caller="attribute"
+            dtype, dformat, enum_labels = get_attribute_type_format(
+                dtype, dformat, kwargs.get("enum_labels")
             )
+            kwargs["dtype"], kwargs["dformat"] = dtype, dformat
+            if enum_labels:
+                kwargs["enum_labels"] = enum_labels
         self.build_from_dict(kwargs)
 
     def get_attribute(self, obj):
@@ -1485,11 +1591,26 @@ def command(
         )
     name = f.__name__
 
-    dtype_format_in = _get_tango_type_format(dtype_in, dformat_in)
-    dtype_format_out = _get_tango_type_format(dtype_out, dformat_out)
+    annotations = getfullargspec(f).annotations
+    args = getfullargspec(f).args
 
-    din = [from_typeformat_to_type(*dtype_format_in), doc_in]
-    dout = [from_typeformat_to_type(*dtype_format_out), doc_out]
+    if dtype_out is None and "return" in annotations:
+        dtype_out, dformat_out, _, _ = parse_type_hint(
+            annotations["return"], caller="command"
+        )
+
+    annotations.pop("return", None)
+
+    if dtype_in is None and len(args) > 1 and len(annotations):
+        dtype_in, dformat_in, _, _ = parse_type_hint(
+            list(annotations.values())[-1], caller="command"
+        )
+
+    dtype_in, format_in, _ = get_attribute_type_format(dtype_in, dformat_in, None)
+    dtype_out, format_out, _ = get_attribute_type_format(dtype_out, dformat_out, None)
+
+    din = [from_typeformat_to_type(dtype_in, format_in), doc_in]
+    dout = [from_typeformat_to_type(dtype_out, format_out), doc_out]
 
     config_dict = {}
     if display_level is not None:
@@ -1507,8 +1628,8 @@ def command(
         def cmd(self, *args, **kwargs):
             return get_worker().execute(f, self, *args, **kwargs)
 
-    if _coverage_run_active:
-        cmd = _force_threading_trace_hook(cmd)
+    if _force_tracing:
+        cmd = _forcefully_traced_method(cmd)
 
     cmd.__tango_command__ = name, [din, dout, config_dict]
 
@@ -1525,9 +1646,10 @@ def command(
 
 
 class _BaseProperty:
-    def __init__(self, dtype, doc="", default_value=None, update_db=False):
+    def __init__(self, dtype=None, doc="", default_value=None, update_db=False):
         self.name = None
-        dtype = from_typeformat_to_type(*_get_tango_type_format(dtype))
+        if dtype:
+            dtype = from_typeformat_to_type(*get_tango_type_format(dtype))
         self.dtype = dtype
         self.doc = doc
         self.default_value = default_value
@@ -1579,7 +1701,7 @@ class device_property(_BaseProperty):
     """
 
     def __init__(
-        self, dtype, doc="", mandatory=False, default_value=None, update_db=False
+        self, dtype=None, doc="", mandatory=False, default_value=None, update_db=False
     ):
         super().__init__(dtype, doc, default_value, update_db)
         self.mandatory = mandatory
@@ -1620,28 +1742,27 @@ class class_property(_BaseProperty):
     pass
 
 
-def __to_cb(post_init_callback):
-    if post_init_callback is None:
+def __to_cb(callback, cb_type):
+    if callback is None:
         return lambda: None
 
     err_msg = (
-        "post_init_callback must be a callable or "
-        "sequence <callable [, args, [, kwargs]]>"
+        f"{cb_type} must be a callable or " "sequence <callable [, args, [, kwargs]]>"
     )
-    if callable(post_init_callback):
-        f = post_init_callback
-    elif is_non_str_seq(post_init_callback):
-        length = len(post_init_callback)
+    if callable(callback):
+        f = callback
+    elif is_non_str_seq(callback):
+        length = len(callback)
         if length < 1 or length > 3:
             raise TypeError(err_msg)
-        cb = post_init_callback[0]
+        cb = callback[0]
         if not callable(cb):
             raise TypeError(err_msg)
         args, kwargs = [], {}
         if length > 1:
-            args = post_init_callback[1]
+            args = callback[1]
         if length > 2:
-            kwargs = post_init_callback[2]
+            kwargs = callback[2]
         f = functools.partial(cb, *args, **kwargs)
     else:
         raise TypeError(err_msg)
@@ -1726,6 +1847,7 @@ def __server_run(
     msg_stream=sys.stdout,
     util=None,
     event_loop=None,
+    pre_init_callback=None,
     post_init_callback=None,
     green_mode=None,
 ):
@@ -1736,7 +1858,8 @@ def __server_run(
     if args is None:
         args = sys.argv
 
-    post_init_callback = __to_cb(post_init_callback)
+    pre_init_callback = __to_cb(pre_init_callback, "pre_init_callback")
+    post_init_callback = __to_cb(post_init_callback, "post_init_callback")
 
     if util is None:
         util = Util.init(args)
@@ -1755,6 +1878,7 @@ def __server_run(
 
     def tango_loop():
         log.debug("server loop started")
+        worker.execute(pre_init_callback)
         _add_classes(util, classes)
         util.server_init()
         worker.execute(post_init_callback)
@@ -1773,6 +1897,7 @@ def run(
     verbose=False,
     util=None,
     event_loop=None,
+    pre_init_callback=None,
     post_init_callback=None,
     green_mode=None,
     raises=False,
@@ -1858,6 +1983,16 @@ def run(
     :param event_loop: event_loop callable
     :type event_loop: callable
 
+    :param pre_init_callback:
+        an optional callback that is executed between the calls
+        Util.init and Util.server_init
+        The optional `pre_init_callback` can be a callable (without
+        arguments) or a tuple where the first element is the callable,
+        the second is a list of arguments (optional) and the third is a
+        dictionary of keyword arguments (also optional).
+    :type pre_init_callback:
+        callable or tuple
+
     :param post_init_callback:
         an optional callback that is executed between the calls
         Util.server_init and Util.server_run
@@ -1883,6 +2018,9 @@ def run(
 
     .. versionchanged:: 9.2.2
         `raises` argument has been added
+
+    .. versionchanged:: 9.5.0
+        `pre_init_callback` argument has been added
     """
     server_run = functools.partial(
         __server_run,
@@ -1891,6 +2029,7 @@ def run(
         msg_stream=msg_stream,
         util=util,
         event_loop=event_loop,
+        pre_init_callback=pre_init_callback,
         post_init_callback=post_init_callback,
         green_mode=green_mode,
     )
@@ -1921,6 +2060,7 @@ def server_run(
     verbose=False,
     util=None,
     event_loop=None,
+    pre_init_callback=None,
     post_init_callback=None,
     green_mode=None,
 ):
@@ -1946,6 +2086,9 @@ def server_run(
     .. deprecated:: 8.1.2
         Use :func:`~tango.server.run` instead.
 
+    .. versionchanged:: 9.5.0
+        `pre_init_callback` argument has been added
+
     """
     return run(
         classes,
@@ -1954,6 +2097,7 @@ def server_run(
         verbose=verbose,
         util=util,
         event_loop=event_loop,
+        pre_init_callback=pre_init_callback,
         post_init_callback=post_init_callback,
         green_mode=green_mode,
     )
@@ -1968,4 +2112,4 @@ class Device(BaseDevice, metaclass=DeviceMeta):
 
 
 # Avoid circular imports
-from .tango_object import Server  # noqa: E402
+from tango.tango_object import Server  # noqa: E402
