@@ -18,15 +18,16 @@ import weakref
 from inspect import getfullargspec
 import inspect
 import functools
+import numpy
 
-from .codec import loads, dumps
-from .attr_data import AttrData
-from .utils import TO_TANGO_TYPE
-from ._tango import AttrDataFormat, CmdArgType, GreenMode
-from ._tango import DbDevInfo, Database, DevState, constants
-from .server import Device, _to_classes, _add_classes
-from .device_server import get_worker, set_worker
-from .green import get_executor
+from tango.codec import loads, dumps
+from tango.attr_data import AttrData
+from tango.utils import TO_TANGO_TYPE
+from tango._tango import AttrDataFormat, CmdArgType, GreenMode
+from tango._tango import DbDevInfo, Database, DevState
+from tango.server import Device, _to_classes, _add_classes
+from tango.device_server import get_worker, set_worker
+from tango.green import get_executor
 
 __all__ = ("Server",)
 
@@ -55,11 +56,7 @@ def __to_tango_type_fmt(value):
     dtype = TO_TANGO_TYPE.get(value_t)
     max_dim_x, max_dim_y = 1, 0
     if dtype is None:
-        if constants.NUMPY_SUPPORT:
-            import numpy
-        else:
-            numpy = None
-        if numpy and isinstance(value, numpy.ndarray):
+        if isinstance(value, numpy.ndarray):
             dtype = TO_TANGO_TYPE.get(value.dtype.name)
             shape_l = len(value.shape)
             if shape_l == 1:
