@@ -3,15 +3,14 @@
 
 # Imports
 import os
-import sys
 import time
 import struct
 import socket
 import tempfile
 import traceback
 import collections
-from functools import partial
 import psutil
+from functools import partial
 
 # Concurrency imports
 import threading
@@ -24,9 +23,14 @@ from importlib import import_module
 from argparse import ArgumentParser, ArgumentTypeError
 
 # Local imports
-from .server import run
-from .utils import is_non_str_seq
-from . import Database, DeviceProxy, DevFailed, Util
+from tango.server import run
+from tango.utils import (
+    _clear_test_context_tango_host_fqtrl,
+    is_non_str_seq,
+    _set_test_context_tango_host_fqtrl,
+)
+from tango.green import switch_existing_global_executors_to_thread
+from tango import DeviceProxy, Database, DevFailed, Util
 
 __all__ = (
     "MultiDeviceTestContext",
@@ -46,6 +50,8 @@ IOR = collections.namedtuple(
     "length major minor wtf host_length host port body",
 )
 
+NO_DB_FRAGMENT = "dbase=no"
+
 
 def ascii_to_bytes(s):
     convert = lambda x: bytes((int(x, 16),))
@@ -73,7 +79,7 @@ def get_server_host_port():
     return ior.host.decode(), ior.port
 
 
-def get_server_port_via_pid(pid, host):
+def get_server_port_via_pid(pid, host, retries=400, delay=0.03):
     """Return the TCP port that a device server process is listening on (GIOP).
 
     This checks TCP sockets open on the process with the given PID, and attempts
@@ -91,6 +97,10 @@ def get_server_port_via_pid(pid, host):
     IP address of a non-loopback network interface, etc.  Note that starting a device
     server on "localhost" may fail if OmniORB creates an IPv6-only socket.
     :type pid: str
+    :param retries: number of times to retry attempts, optional
+    :type retries: int
+    :param delay: time to wait (seconds) between retries, optional
+    :type delay: float
 
     :returns: TCP port number
     :rtype: int
@@ -98,15 +108,35 @@ def get_server_port_via_pid(pid, host):
     :raises RuntimeError: If the GIOP port couldn't be identified
 
     .. versionadded:: 9.4.0
+    .. versionadded:: 9.5.0
+        *retries* parameter.
+        *delay* parameter.
     """
-    ports = _get_listening_tcp_ports(pid)
-    return _get_giop_port(host, ports)
+
+    count = 0
+    port = None
+    last_err = None
+    while port is None and count < retries:
+        ports = _get_listening_tcp_ports(pid)
+        try:
+            port = _get_giop_port(host, ports)
+        except Exception as err:
+            last_err = err
+            time.sleep(delay)
+        count += 1
+
+    if port is None:
+        raise RuntimeError(
+            f"Failed to get GIOP TCP port within {count * delay:.1f} sec"
+        ) from last_err
+
+    return port
 
 
 def _get_listening_tcp_ports(pid):
     p = psutil.Process(pid)
     conns = p.connections(kind="tcp")
-    return [c.laddr[1] for c in conns]
+    return list(set([c.laddr[1] for c in conns]))
 
 
 def _get_giop_port(host, ports):
@@ -188,18 +218,18 @@ def device(path):
 def get_host_ip():
     """Get the primary external host IP.
 
-    This is useful because an explicit IP is required to get
-    tango events to work properly. Note that localhost does not work
-    either.
+    This is used to be useful because an explicit IP was required to get
+    tango events to work properly.  Now remains for backwards compatibility.
     """
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     # Connecting to a UDP address doesn't send packets
     # Note:  For some reason Python3 on macOS does not accept 0 as a port but
-    # returns with an errno 49 instead. Therefore just use port 80 which just
+    # returns with an errno 49 instead. Therefore, just use port 80 which just
     # works as well.
     s.connect(("8.8.8.8", 80))
     # Get ip address
     ip = s.getsockname()[0]
+    s.close()
     return ip
 
 
@@ -233,49 +263,48 @@ class MultiDeviceTestContext:
 
     Example usage::
 
+        from tango import DeviceProxy
         from tango.server import Device, attribute
         from tango.test_context import MultiDeviceTestContext
 
 
         class Device1(Device):
-
-            @attribute
+            @attribute(dtype=int)
             def attr1(self):
-                return 1.0
+                return 1
 
 
         class Device2(Device):
-
-            @attribute
-            def read_attr2(self):
-                return 2.0
+            @attribute(dtype=int)
+            def attr2(self):
+                dev1 = DeviceProxy("test/device/1")
+                return dev1.attr1 * 2
 
 
         devices_info = (
             {
                 "class": Device1,
                 "devices": [
-                    {
-                        "name": "test/device1/1"
-                    },
-                ]
+                    {"name": "test/device/1"},
+                ],
             },
             {
                 "class": Device2,
                 "devices": [
                     {
-                        "name": "test/device2/1",
+                        "name": "test/device/2",
                     },
-                ]
-            }
+                ],
+            },
         )
 
+
         def test_devices():
             with MultiDeviceTestContext(devices_info, process=True) as context:
-                proxy1 = context.get_device("test/device1/1")
-                proxy2 = context.get_device("test/device2/1")
-                assert proxy1.attr1 == 1.0
-                assert proxy2.attr2 == 2.0
+                proxy1 = context.get_device("test/device/1")
+                proxy2 = context.get_device("test/device/2")
+                assert proxy1.attr1 == 1
+                assert proxy2.attr2 == 2
 
     :param devices_info:
       a sequence of dicts with information about
@@ -283,17 +312,18 @@ class MultiDeviceTestContext:
 
         * "class" which value is either of:
 
-          * :class:`~tango.server.Device` or the name of some such class
+          * a :class:`~tango.server.Device` or the name of some such class
           * a sequence of two elements, the first element being a
             :class:`~tango.DeviceClass` or the name of some such class,
             the second element being a :class:`~tango.DeviceImpl` or the
-            name of such such class
+            name of some such class
 
         * "devices" which value is a sequence of dicts with the following keys:
 
           * "name" (str)
           * "properties" (dict)
           * "memorized" (dict)
+          * "root_atts" (dict)"
 
     :type devices_info:
       sequence<dict>
@@ -316,7 +346,7 @@ class MultiDeviceTestContext:
       :py:obj:`str`
     :param host:
       Hostname to use for device server's ORB endpoint.
-      Optional.  Default is a local IP address.
+      Optional.  Default is the loopback IP address, 127.0.0.1.
     :type host:
       :py:obj:`str`
     :param port:
@@ -356,10 +386,27 @@ class MultiDeviceTestContext:
       or if that isn't specified the global green mode.
     :type green_mode:
       :obj:`~tango.GreenMode`
+
+    .. versionadded:: 9.3.2
+
+    .. versionadded:: 9.3.3
+        Added support for `memorized` key to "devices" field in `devices_info`.
+        Added support for literal names for "class" field in `devices_info`.
+
+    .. versionadded:: 9.3.3
+        added *green_mode* parameter.
+
+    .. versionchanged:: 9.5.0
+        By default, devices launched by a test context can be accessed using
+        short names with :class:`~tango.AttributeProxy`, :class:`~tango.DeviceProxy`,
+        and :class:`~tango.Group`.
+        This can be disabled by setting the `enable_test_context_tango_host_override`
+        class/instance attribute to `False` before starting the test context.
+        Added support for `root_atts` key to "devices" field in `devices_info`.
     """
 
-    nodb = "dbase=no"
     command = "{0} {1} -ORBendPoint giop:tcp:{2}:{3} -file={4}"
+    enable_test_context_tango_host_override = True
 
     thread_timeout = _DEFAULT_THREAD_TIMEOUT
     process_timeout = _DEFAULT_PROCESS_TIMEOUT
@@ -389,21 +436,25 @@ class MultiDeviceTestContext:
         else:
             self.handle = None
         if host is None:
-            # IP address is used instead of the hostname on purpose (see #246)
-            host = get_host_ip()
+            host = "127.0.0.1"  # note: localhost does not currently work
         if timeout is None:
             timeout = self.process_timeout if process else self.thread_timeout
-        # Patch bug #819
-        if process:
-            os.environ["ORBscanGranularity"] = "0"
         # Attributes
         self.db = db
         self.host = host
         self.port = port
         self.timeout = timeout
         self.server_name = "/".join(("dserver", server_name, instance_name))
-        self.queue = multiprocessing.Queue() if process else queue.Queue()
+        if process:
+            self._startup_exception_queue = multiprocessing.Queue()
+            self._discovered_port_queue = multiprocessing.JoinableQueue()
+        else:
+            self._startup_exception_queue = queue.Queue()
+            self._discovered_port_queue = queue.Queue()
+        self._startup_exception = None
         self._devices = {}
+        self._saved_environ = {}
+        self._process = process
 
         # Command args
         string = self.command.format(server_name, instance_name, host, port, db)
@@ -452,34 +503,64 @@ class MultiDeviceTestContext:
         self.thread.daemon = daemon
 
     def target(self, runserver, process=False):
+        threading.current_thread().name += " TestContext DS launcher"
         try:
-            runserver(post_init_callback=self.post_init, raises=True)
-        except Exception:
-            # Put exception in the queue
-            etype, value, tb = sys.exc_info()
-            if process:
-                tb = None  # Traceback objects can't be pickled
-            self.queue.put((etype, value, tb))
+            runserver(
+                pre_init_callback=self.pre_init,
+                post_init_callback=self.post_init,
+                raises=True,
+            )
+        except Exception as exc:
+            self._startup_exception_queue.put(exc)
+            self._discovered_port_queue.put(-1)  # don't block queue reader
         finally:
             # Put something in the queue just in case
             exc = RuntimeError("The server failed to report anything")
-            self.queue.put((None, exc, None))
+            self._startup_exception_queue.put(exc)
             # Make sure the process has enough time to send the items
-            # because the it might segfault while cleaning up the
-            # the tango resources
+            # because it might segfault while cleaning up the tango resources
             if process:
                 time.sleep(0.1)
 
-    def post_init(self):
+    def pre_init(self):
         try:
-            host, port = get_server_host_port()
-            self.queue.put((host, port))
+            if not self.port:
+                util = Util.instance()
+                pid = util.get_pid()
+                self.port = get_server_port_via_pid(pid, self.host)
+            if self._process:
+                # set TANGO_HOST override for device server (DS) launcher child process
+                self._override_test_context_tango_host()
+            # report it to the test context process (DS launcher's parent)
+            self._discovered_port_queue.put(self.port)
+            # and wait till it has been processed
+            self._discovered_port_queue.join()
         except Exception as exc:
-            self.queue.put((None, exc, None))
-        finally:
-            # Put something in the queue just in case
-            exc = RuntimeError("The post_init routine failed to report anything")
-            self.queue.put((None, exc, None))
+            self._startup_exception_queue.put(exc)
+            self._discovered_port_queue.put(-1)  # don't block queue reader
+
+    def _wait_until_port_is_known(self):
+        try:
+            self.port = self._discovered_port_queue.get(timeout=self.timeout)
+        except queue.Empty:
+            raise RuntimeError(
+                "GIOP TCP port of TextContext device server not available during startup"
+            )
+
+        # set the TANGO_HOST override for the process that created the test context
+        self._override_test_context_tango_host()
+        # notify the server process, so it can continue
+        self._discovered_port_queue.task_done()
+
+    def _override_test_context_tango_host(self):
+        if self.enable_test_context_tango_host_override:
+            _set_test_context_tango_host_fqtrl(
+                f"tango://{self.host}:{self.port}#{NO_DB_FRAGMENT}"
+            )
+
+    def post_init(self):
+        # now we can connect to the device - success!
+        self._startup_exception_queue.put(None)
 
     def append_db_file(self, server, instance, tangoclass, device_prop_info):
         """Generate a database file corresponding to the given arguments."""
@@ -504,12 +585,20 @@ class MultiDeviceTestContext:
                     properties[key] = value if value != "" else " "
             db.put_device_property(device_name, properties)
 
-            memorized = info.get("memorized", {})
-            munged = {
-                attribute_name: {"__value": memorized_value}
-                for (attribute_name, memorized_value) in memorized.items()
+            root_atts = info.get("root_atts", {})
+            properties_to_save = {
+                attribute_name: {"__root_att": root_att}
+                for (attribute_name, root_att) in root_atts.items()
             }
-            db.put_device_attribute_property(device_name, munged)
+
+            memorized = info.get("memorized", {})
+            for attribute_name, memorized_value in memorized.items():
+                if attribute_name in properties_to_save:
+                    properties_to_save[attribute_name]["__value"] = memorized_value
+                else:
+                    properties_to_save[attribute_name] = {"__value": memorized_value}
+
+            db.put_device_attribute_property(device_name, properties_to_save)
         try:
             validated_db = Database(self.db)
         except DevFailed:
@@ -531,11 +620,11 @@ class MultiDeviceTestContext:
 
     def get_server_access(self):
         """Return the full server name."""
-        return f"tango://{self.host}:{self.port}/{self.server_name}#{self.nodb}"
+        return f"tango://{self.host}:{self.port}/{self.server_name}#{NO_DB_FRAGMENT}"
 
     def get_device_access(self, device_name):
         """Return the full device name."""
-        return f"tango://{self.host}:{self.port}/{device_name}#{self.nodb}"
+        return f"tango://{self.host}:{self.port}/{device_name}#{NO_DB_FRAGMENT}"
 
     def get_device(self, device_name):
         """Return the device proxy corresponding to the given device name.
@@ -550,14 +639,16 @@ class MultiDeviceTestContext:
 
     def start(self):
         """Run the server."""
+        self._set_up_environment_variables()
         self.thread.start()
         self.connect()
         return self
 
     def connect(self):
         try:
-            args = self.queue.get(timeout=self.timeout)
-        except queue.Empty:
+            self._wait_until_port_is_known()
+            self._wait_until_startup_status_is_known()
+        except RuntimeError:
             if self.thread.is_alive():
                 raise RuntimeError(
                     "The server appears to be stuck at initialization. "
@@ -573,21 +664,28 @@ class MultiDeviceTestContext:
                     "The server stopped without reporting. "
                     "Check stdout/stderr for more information."
                 )
-        try:
-            self.host, self.port = args
-        except ValueError as e:
-            # Warning: an assumption made here - if the args don't contain the
-            #          expected (host, port) items then we assume the args contain
-            #          exception info.
-            if len(args) == 3:
-                exc_type, exc_value, exc_traceback = args
-                raise exc_value
-            # In case the above assumption is wrong: re-raise the original exception
-            raise ValueError(*args) from e
+
+        if self._startup_exception:
+            raise self._startup_exception
+
         # Get server proxy
         self.server = DeviceProxy(self.get_server_access())
         self.server.ping()
 
+        # If server has green_mode, we should switch global executor to the main thread
+        if not self._process:
+            switch_existing_global_executors_to_thread()
+
+    def _wait_until_startup_status_is_known(self):
+        try:
+            self._startup_exception = self._startup_exception_queue.get(
+                timeout=self.timeout
+            )
+        except queue.Empty:
+            raise RuntimeError(
+                f"Timed-out waiting for device server startup ({self.timeout:1.3f} sec)"
+            )
+
     def stop(self):
         """Kill the server."""
         try:
@@ -595,11 +693,30 @@ class MultiDeviceTestContext:
                 self.server.command_inout("Kill")
             self.join(self.timeout)
         finally:
+            _clear_test_context_tango_host_fqtrl()
             self.delete_db()
+            self._restore_environment_variables()
 
     def join(self, timeout=None):
         self.thread.join(timeout)
 
+    def _set_up_environment_variables(self):
+        self._saved_environ = dict(os.environ)
+        # Patch bug #819
+        if self._process:
+            os.environ["ORBscanGranularity"] = "0"
+
+    def _restore_environment_variables(self):
+        modified_environ = dict(os.environ)
+        saved_environ = self._saved_environ
+        for key, value in modified_environ.items():
+            if key in saved_environ:
+                saved_value = saved_environ[key]
+                if value != saved_value:
+                    os.environ[key] = saved_value
+            else:
+                os.environ.pop(key)  # unset environment var
+
     def __enter__(self):
         """Enter method for context support.
 
@@ -663,6 +780,14 @@ class DeviceTestContext(MultiDeviceTestContext):
 
      The rest of the parameters are described in
      :class:`~tango.test_context.MultiDeviceTestContext`.
+
+    .. versionadded:: 9.2.1
+
+    .. versionadded:: 9.3.3
+        added *memorized* parameter.
+
+    .. versionadded:: 9.3.6
+        added *green_mode* parameter.
     """
 
     def __init__(
@@ -681,6 +806,7 @@ class DeviceTestContext(MultiDeviceTestContext):
         daemon=False,
         timeout=None,
         memorized=None,
+        root_atts=None,
         green_mode=None,
     ):
         # Argument
@@ -694,6 +820,8 @@ class DeviceTestContext(MultiDeviceTestContext):
             properties = {}
         if memorized is None:
             memorized = {}
+        if root_atts is None:
+            root_atts = {}
         if device_cls:
             cls = (device_cls, device)
         else:
@@ -706,6 +834,7 @@ class DeviceTestContext(MultiDeviceTestContext):
                         "name": device_name,
                         "properties": properties,
                         "memorized": memorized,
+                        "root_atts": root_atts,
                     },
                 ),
             },
@@ -763,7 +892,9 @@ def parse_command_line_args(args=None):
     msg = "The device to run as a python path."
     parser.add_argument("device", metavar="DEVICE", type=device, help=msg)
     msg = "The hostname to use."
-    parser.add_argument("--host", metavar="HOST", type=str, help=msg, default=None)
+    parser.add_argument(
+        "--host", metavar="HOST", type=str, help=msg, default=get_host_ip()
+    )
     msg = "The port to use."
     parser.add_argument("--port", metavar="PORT", type=int, help=msg, default=8888)
     msg = "The debug level."
@@ -772,6 +903,13 @@ def parse_command_line_args(args=None):
     parser.add_argument(
         "--prop", metavar="PROP", type=literal_dict, help=msg, default="{}"
     )
+    msg = "Whether to disable short-name lookup for devices launched by test context"
+    parser.add_argument(
+        "--disable-short-name-lookup",
+        dest="disable_short_name_lookup",
+        action="store_true",
+        help=msg,
+    )
     # Parse arguments
     namespace = parser.parse_args(args)
     return (
@@ -780,18 +918,25 @@ def parse_command_line_args(args=None):
         namespace.port,
         namespace.prop,
         namespace.debug,
+        namespace.disable_short_name_lookup,
     )
 
 
 def run_device_test_context(args=None):
-    device, host, port, properties, debug = parse_command_line_args(args)
+    (
+        device_,
+        host,
+        port,
+        properties,
+        debug,
+        disable_short_name_lookup,
+    ) = parse_command_line_args(args)
     context = DeviceTestContext(
-        device, properties=properties, host=host, port=port, debug=debug
+        device_, properties=properties, host=host, port=port, debug=debug
     )
+    context.enable_test_context_tango_host_override = not disable_short_name_lookup
     context.start()
-    msg = (
-        f"{device.__name__} started on port {context.port} with properties {properties}"
-    )
+    msg = f"{device_.__name__} started on port {context.port} with properties {properties}"
     print(msg)
     print(f"Device access: {context.get_device_access()}")
     print(f"Server access: {context.get_server_access()}")
