@@ -3,18 +3,19 @@
 import enum
 import numpy as np
 
+try:
+    import numpy.typing as npt
+except ImportError:
+    npt = None
+
 from functools import wraps
 
 # Local imports
-from . import DevState, GreenMode, AttrDataFormat, ExtractAs
-from .server import Device
-from .test_context import (
-    MultiDeviceTestContext,
-    DeviceTestContext,
-    get_server_port_via_pid,
-)
-from .utils import is_non_str_seq, FROM_TANGO_TO_NUMPY_TYPE
-from . import DeviceClass, LatestDeviceImpl, DevLong64, SCALAR, READ
+from tango import DevState, GreenMode, AttrDataFormat, ExtractAs, DevFailed
+from tango.server import Device
+from tango.test_context import MultiDeviceTestContext, DeviceTestContext
+from tango.utils import is_non_str_seq, FROM_TANGO_TO_NUMPY_TYPE
+from tango import DeviceClass, LatestDeviceImpl, DevLong64, SCALAR, READ
 
 # Conditional imports
 try:
@@ -22,7 +23,7 @@ try:
 except ImportError:
     pytest = None
 
-__all__ = (
+__all__ = [
     "MultiDeviceTestContext",
     "DeviceTestContext",
     "SimpleDevice",
@@ -34,8 +35,18 @@ __all__ = (
     "dev_encoded_values",
     "server_green_mode",
     "attr_data_format",
-    "get_server_port_via_pid",
-)
+    "convert_dtype_to_typing_hint",
+    "assert_close",
+    "general_decorator",
+    "DEVICE_SERVER_ARGUMENTS",
+]
+
+if npt:
+    __all__ += [
+        "command_numpy_typed_values",
+        "attribute_numpy_typed_values",
+        "attribute_wrong_numpy_typed",
+    ]
 
 UTF8_STRING = (
     r"""ăѣ𝔠ծềſģȟᎥ𝒋ǩľḿꞑȯ𝘱𝑞𝗋𝘴ȶ𝞄𝜈ψ𝒙𝘆𝚣1234567890!@#$%^&*()-_=+[{]};:'",<.>/?~𝘈Ḇ𝖢𝕯٤ḞԍНǏ𝙅ƘԸⲘ𝙉০Ρ𝗤Ɍ𝓢ȚЦ𝒱Ѡ𝓧ƳȤ"""
@@ -132,8 +143,8 @@ GENERAL_TYPED_VALUES = {
         np.array(["foo", "bar"]),
         ["ab", "cd", "ef"],
         ["gh", "ij", "kl"],
-        10 * [bytes_devstring],
-        10 * [str_devstring],
+        3 * [bytes_devstring],
+        3 * [str_devstring],
     ),
     (bool,): (
         np.array([True, False]),
@@ -158,8 +169,8 @@ IMAGE_TYPED_VALUES = {
     ((str,),): (
         np.vstack((np.array(["hi-hi", "ha-ha"]), np.array(["hu-hu", "yuhuu"]))),
         [["ab", "cd", "ef"], ["gh", "ij", "kl"]],
-        [10 * [bytes_devstring], 10 * [bytes_devstring]],
-        [10 * [str_devstring], 10 * [str_devstring]],
+        [3 * [bytes_devstring], 3 * [bytes_devstring]],
+        [3 * [str_devstring], 3 * [str_devstring]],
     ),
     ((bool,),): (
         np.vstack((np.array([True, False]), np.array([False, True]))),
@@ -169,6 +180,68 @@ IMAGE_TYPED_VALUES = {
     ),
 }
 
+_numpy_hits_source = (
+    ((np.bool_,), True, [True, False], [[True, False], [False, True]]),
+    ((np.ubyte,), 1, [1, 2], [[1, 2], [3, 4]]),
+    (
+        (
+            np.short,
+            np.ushort,
+            np.int32,
+            np.uint32,
+            np.int64,
+            np.uint64,
+        ),
+        1,
+        [1, 2],
+        [[1, 2], [3, 4]],
+    ),
+    (
+        (
+            np.float64,
+            np.float32,
+        ),
+        1.1,
+        [1.1, 2.2],
+        [[1.1, 2.2], [3.3, 4.4]],
+    ),
+)
+
+
+if npt:
+    NUMPY_GENERAL_TYPING_HINTS = []
+    NUMPY_IMAGES_TYPING_HINTS = []
+    for dtypes, scalar, spectrum, image in _numpy_hits_source:
+        for dtype in dtypes:
+            NUMPY_GENERAL_TYPING_HINTS.extend(
+                [
+                    [dtype, dtype, AttrDataFormat.SCALAR, scalar],
+                    [dtype, npt.NDArray[dtype], AttrDataFormat.SPECTRUM, spectrum],
+                ]
+            )
+            NUMPY_IMAGES_TYPING_HINTS.append(
+                [dtype, npt.NDArray[dtype], AttrDataFormat.IMAGE, image]
+            )
+
+    WRONG_NUMPY_TYPING_HINTS = (  # dformat, max_x, max_y, value, error, match
+        (None, None, None, None, RuntimeError, "AttrDataFormat has to be specified"),
+        (
+            AttrDataFormat.IMAGE,
+            3,
+            0,
+            [[1, 2], [3, 4]],
+            DevFailed,
+            "Maximum y dim. wrongly defined",
+        ),
+        (
+            AttrDataFormat.SPECTRUM,
+            3,
+            0,
+            [[1, 2], [3, 4]],
+            TypeError,
+            "No registered converter",
+        ),
+    )
 
 EXTRACT_AS = [
     (ExtractAs.Numpy, np.ndarray),
@@ -279,6 +352,29 @@ DEVICE_SERVER_ARGUMENTS = (
 )
 
 
+def convert_dtype_to_typing_hint(dtype):
+    check_x_dim, check_y_dim = False, False
+    if type(dtype) is tuple:
+        dtype = dtype[0]
+        check_x_dim = True
+        if type(dtype) is tuple:
+            dtype = dtype[0]
+            check_y_dim = True
+            tuple_hint = tuple[
+                tuple[dtype, dtype, dtype],
+                tuple[dtype, dtype, dtype],
+            ]
+            list_hint = list[list[dtype]]
+        else:
+            tuple_hint = tuple[dtype, dtype, dtype]
+            list_hint = list[dtype]
+    else:
+        tuple_hint = dtype
+        list_hint = dtype
+
+    return tuple_hint, list_hint, check_x_dim, check_y_dim
+
+
 def general_decorator(function=None):
     if function:
 
@@ -297,8 +393,55 @@ def repr_type(x):
     return f"{x.__name__}"
 
 
-# Numpy helpers
+def repr_numpy_type(dtype, dformat):
+    if dformat == AttrDataFormat.SCALAR:
+        return f"{dtype.__name__}, SCALAR"
+    elif dformat == AttrDataFormat.SPECTRUM:
+        return f"np.NDarray[{dtype.__name__}], SPECTRUM"
+    else:
+        return f"np.n2array[{dtype.__name__}], IMAGE"
 
+
+# helpers to test enums
+def check_attr_type(read_attr, attr_data_format, desired_type):
+    if attr_data_format == AttrDataFormat.SCALAR:
+        assert isinstance(read_attr, desired_type)
+    elif attr_data_format == AttrDataFormat.SPECTRUM:
+        for state in read_attr:
+            assert isinstance(state, desired_type)
+    else:
+        for state in read_attr:
+            for stat in state:
+                assert isinstance(stat, desired_type)
+
+
+def assert_value_label(read_attr, value, label):
+    assert read_attr.value == value
+    assert read_attr.name == label
+
+
+def check_read_attr(read_attr, attr_data_format, value, label):
+    if attr_data_format == AttrDataFormat.SCALAR:
+        assert_value_label(read_attr, value, label)
+    elif attr_data_format == AttrDataFormat.SPECTRUM:
+        for val in read_attr:
+            assert_value_label(val, value, label)
+    else:
+        for val in read_attr:
+            for v in val:
+                assert_value_label(v, value, label)
+
+
+def make_nd_value(value, attr_data_format):
+    if attr_data_format == AttrDataFormat.SCALAR:
+        return value
+    elif attr_data_format == AttrDataFormat.SPECTRUM:
+        return (value,)
+    else:
+        return ((value,),)
+
+
+# Numpy helpers
 if pytest:
 
     def __assert_all_types(a, b):
@@ -367,6 +510,54 @@ if pytest:
         expected = lambda v: create_result(dtype, v)
         return dtype, values, expected
 
+    if npt:
+
+        @pytest.fixture(
+            params=NUMPY_GENERAL_TYPING_HINTS, ids=lambda x: repr_numpy_type(x[0], x[2])
+        )
+        def command_numpy_typed_values(request):
+            dtype, type_hint, dformat, values = request.param
+            expected = lambda v: create_result(dtype, v)
+            return type_hint, dformat, values, expected
+
+        @pytest.fixture(
+            params=NUMPY_GENERAL_TYPING_HINTS + NUMPY_IMAGES_TYPING_HINTS,
+            ids=lambda x: repr_numpy_type(x[0], x[2]),
+        )
+        def attribute_numpy_typed_values(request):
+            dtype, type_hint, dformat, values = request.param
+            expected = lambda v: create_result(dtype, v)
+            return type_hint, dformat, values, expected
+
+        @pytest.fixture(
+            params=WRONG_NUMPY_TYPING_HINTS, ids=lambda x: f"{x[-2].__name__}: {x[-1]}"
+        )
+        def attribute_wrong_numpy_typed(request):
+            return request.param
+
+    else:
+
+        @pytest.fixture
+        def command_numpy_typed_values(request):
+            raise RuntimeError(
+                f"Numpy typing supported only for Numpy >= 1.20, "
+                f"while current version is {np.version.version}"
+            )
+
+        @pytest.fixture
+        def attribute_numpy_typed_values(request):
+            raise RuntimeError(
+                f"Numpy typing supported only for Numpy >= 1.20, "
+                f"while current version is {np.version.version}"
+            )
+
+        @pytest.fixture
+        def attribute_wrong_numpy_typed(request):
+            raise RuntimeError(
+                f"Numpy typing supported only for Numpy >= 1.20, "
+                f"while current version is {np.version.version}"
+            )
+
     @pytest.fixture(
         params=list(DEV_ENCODED_DATA.items()),
         ids=list(DEV_ENCODED_DATA.keys()),
