@@ -20,7 +20,7 @@ __docformat__ = "restructuredtext"
 import time
 import datetime
 
-from ._tango import TimeVal
+from tango._tango import TimeVal
 import numbers
 
 
