@@ -14,20 +14,24 @@ This is an internal PyTango module.
 """
 
 
+import collections.abc
 import os
 import sys
 import types
 import numbers
 import inspect
 import enum
-import numpy
+
+import typing
+import numpy as np
 
 from argparse import HelpFormatter
+from urllib.parse import urlparse, urlunparse
+
 from packaging.version import Version
 
-import collections.abc
-
-from ._tango import (
+from tango._tango import (
+    AttrQuality,
     StdStringVector,
     StdDoubleVector,
     DbData,
@@ -40,17 +44,17 @@ from ._tango import (
     AttrConfEventData,
     DataReadyEventData,
     DevFailed,
-    constants,
     DevState,
     CommunicationFailed,
     PipeEventData,
     DevIntrChangeEventData,
     Database,
+    EncodedAttribute,
 )
 
-from . import _tango
-from .constants import AlrmValueNotSpec, StatusNotSet, TgLibVers
-from .release import Release
+from tango import _tango
+from tango.constants import AlrmValueNotSpec, StatusNotSet, TgLibVers
+from tango.release import Release
 
 __all__ = (
     "requires_pytango",
@@ -85,16 +89,27 @@ __all__ = (
     "dir2",
     "TO_TANGO_TYPE",
     "ensure_binary",
+    "_get_device_fqtrl_if_necessary",
+    "_get_test_context_tango_host_fqtrl",
+    "_set_test_context_tango_host_fqtrl",
+    "_clear_test_context_tango_host_fqtrl",
+    "InvalidTangoHostTrlError",
+    "PyTangoUserWarning",
+    "parse_type_hint",
 )
 
 __docformat__ = "restructuredtext"
 
 # Types
 
+__str_klasses = (str,)
+__int_klasses = (int, np.integer)
+__number_klasses = (numbers.Number, np.number)
+__seq_klasses = (collections.abc.Sequence, bytearray, StdStringVector, np.ndarray)
+
 _scalar_int_types = (
     CmdArgType.DevShort,
     CmdArgType.DevUShort,
-    CmdArgType.DevInt,
     CmdArgType.DevLong,
     CmdArgType.DevULong,
     CmdArgType.DevLong64,
@@ -160,17 +175,17 @@ _binary_types = (
 
 
 FROM_TANGO_TO_NUMPY_TYPE = {
-    CmdArgType.DevBoolean: numpy.bool_,
-    CmdArgType.DevUChar: numpy.ubyte,
-    CmdArgType.DevShort: numpy.short,
-    CmdArgType.DevUShort: numpy.ushort,
-    CmdArgType.DevLong: numpy.int32,
-    CmdArgType.DevULong: numpy.uint32,
-    CmdArgType.DevLong64: numpy.int64,
-    CmdArgType.DevULong64: numpy.uint64,
+    CmdArgType.DevBoolean: np.bool_,
+    CmdArgType.DevUChar: np.ubyte,
+    CmdArgType.DevShort: np.short,
+    CmdArgType.DevUShort: np.ushort,
+    CmdArgType.DevLong: np.int32,
+    CmdArgType.DevULong: np.uint32,
+    CmdArgType.DevLong64: np.int64,
+    CmdArgType.DevULong64: np.uint64,
     CmdArgType.DevString: str,
-    CmdArgType.DevDouble: numpy.float64,
-    CmdArgType.DevFloat: numpy.float32,
+    CmdArgType.DevDouble: np.float64,
+    CmdArgType.DevFloat: np.float32,
 }
 
 
@@ -211,11 +226,6 @@ def __build_to_tango_type():
         "blob": CmdArgType.DevPipeBlob,
     }
 
-    try:
-        ret[long] = ret[int]
-    except NameError:
-        pass
-
     for key in dir(CmdArgType):
         if key.startswith("Dev"):
             value = getattr(CmdArgType, key)
@@ -233,7 +243,6 @@ _scalar_to_array_type = {
     CmdArgType.DevUChar: CmdArgType.DevVarCharArray,
     CmdArgType.DevShort: CmdArgType.DevVarShortArray,
     CmdArgType.DevUShort: CmdArgType.DevVarUShortArray,
-    CmdArgType.DevInt: CmdArgType.DevVarLongArray,
     CmdArgType.DevLong: CmdArgType.DevVarLongArray,
     CmdArgType.DevULong: CmdArgType.DevVarULongArray,
     CmdArgType.DevLong64: CmdArgType.DevVarLong64Array,
@@ -386,44 +395,6 @@ def get_latest_device_class():
     return get_tango_device_classes()[-1]
 
 
-try:
-    __str_klasses = (basestring,)
-except NameError:
-    __str_klasses = (str,)
-
-__int_klasses = (int,)
-__number_klasses = (numbers.Number,)
-__seq_klasses = collections.abc.Sequence, bytearray, StdStringVector
-
-__use_unicode = False
-try:
-    unicode
-    __use_unicode = True
-    __str_klasses = tuple(list(__str_klasses) + [unicode])
-except NameError:
-    pass
-
-__use_long = False
-try:
-    long
-    __use_long = True
-    __int_klasses = tuple(list(__int_klasses) + [long])
-except NameError:
-    pass
-
-if constants.NUMPY_SUPPORT:
-    import numpy
-
-    __int_klasses = tuple(list(__int_klasses) + [numpy.integer])
-    __number_klasses = tuple(list(__number_klasses) + [numpy.number])
-    __seq_klasses = tuple(list(__seq_klasses) + [numpy.ndarray])
-
-__str_klasses = tuple(__str_klasses)
-__int_klasses = tuple(__int_klasses)
-__number_klasses = tuple(__number_klasses)
-__seq_klasses = tuple(__seq_klasses)
-
-
 def set_complex_value(attr, value):
     is_tuple = isinstance(value, tuple)
     dtype, fmt = attr.get_data_type(), attr.get_data_format()
@@ -432,6 +403,8 @@ def set_complex_value(attr, value):
             attr.set_value_date_quality(*value)
         elif is_tuple and len(value) == 3 and is_non_str_seq(value[0]):
             attr.set_value_date_quality(value[0][0], value[0][1], *value[1:])
+        elif isinstance(value, EncodedAttribute):
+            attr.set_value(value)
         else:
             attr.set_value(*value)
     else:
@@ -473,7 +446,7 @@ def __get_tango_type(obj):
     return r, AttrDataFormat.SCALAR
 
 
-def __get_tango_type_numpy_support(obj):
+def get_tango_type(obj):
     try:
         ndim, dtype = obj.ndim, str(obj.dtype)
         if ndim > 2:
@@ -486,10 +459,150 @@ def __get_tango_type_numpy_support(obj):
         return __get_tango_type(obj)
 
 
-def get_tango_type(obj):
-    if constants.NUMPY_SUPPORT:
-        return __get_tango_type_numpy_support(obj)
-    return __get_tango_type(obj)
+def get_attribute_type_format(dtype, dformat, enum_labels):
+    if is_enum(dtype) or is_enum_seq(dtype):
+        if enum_labels:
+            raise TypeError(
+                "For dtype of enum.Enum, (enum.Enum,) or ((enum.Enum,),) the enum_labels must not "
+                f"be specified - dtype: {dtype}, enum_labels: {enum_labels}."
+            )
+        _dtype = dtype
+        dtype = CmdArgType.DevEnum
+
+        while is_enum_seq(_dtype):
+            _dtype = _dtype[0]
+            dtype = (dtype,)
+
+        enum_labels = get_enum_labels(_dtype)
+
+    elif is_devstate(dtype) or is_devstate_seq(dtype):
+        _dtype = dtype
+        dtype = CmdArgType.DevState
+
+        while is_devstate_seq(_dtype):
+            _dtype = _dtype[0]
+            dtype = (dtype,)
+
+    return *get_tango_type_format(dtype, dformat, "attribute"), enum_labels
+
+
+def get_tango_type_format(dtype, dformat=None, caller=None):
+    if dformat is None:
+        dformat = AttrDataFormat.SCALAR
+        if is_non_str_seq(dtype):
+            if len(dtype):
+                dtype = dtype[0]
+                dformat = AttrDataFormat.SPECTRUM
+                if is_non_str_seq(dtype):
+                    if len(dtype):
+                        dtype = dtype[0]
+                        dformat = AttrDataFormat.IMAGE
+                    elif caller == "attribute":
+                        raise TypeError(
+                            "Image attribute type must be specified as ((<dtype>,),)"
+                        )
+            elif caller == "attribute":
+                raise TypeError(
+                    "Spectrum attribute type must be specified as (<dtype>,)"
+                )
+
+    try:
+        tango_type = TO_TANGO_TYPE[dtype]
+    except KeyError:
+        raise RuntimeError(
+            f"Cannot translate {dtype} to TANGO type. See documentation for the allowed types"
+        )
+
+    return tango_type, dformat
+
+
+def __has_ellipsis_in_types(dtype):
+    try:
+        list(typing.get_args(dtype)).remove(Ellipsis)
+        return True
+    except ValueError:
+        pass
+
+    return False
+
+
+def __check_types_uniformity(dtype):
+    all_types = list(set(typing.get_args(dtype)))
+    if Ellipsis in all_types:
+        all_types.remove(Ellipsis)
+    if len(all_types) > 1:
+        return False
+    for sub_type in typing.get_args(dtype):
+        if typing.get_origin(sub_type) in [list, tuple]:
+            if not __check_types_uniformity(sub_type):
+                return False
+    return True
+
+
+def parse_type_hint(annotation, caller):
+    dtype = annotation
+    dformat = AttrDataFormat.SCALAR
+    max_x, max_y = None, None
+    if typing.get_origin(dtype) in [list, tuple]:
+        n_elements = len(typing.get_args(dtype))
+        if (
+            n_elements in [2, 4]
+            and typing.get_args(dtype)[0] == str
+            and typing.get_args(dtype)[1] in [bytes, bytearray]
+        ):
+            return "DevEncoded", dformat, max_x, max_y
+        if (
+            n_elements == 3
+            and typing.get_args(dtype)[1] == float
+            and typing.get_args(dtype)[2] == AttrQuality
+        ):
+            dtype = typing.get_args(dtype)[0]
+    if typing.get_origin(dtype) == np.ndarray:
+        dtype = typing.get_args(typing.get_args(dtype)[1])[0]
+        dformat = None
+        if caller in ["property", "command"]:
+            dtype = (dtype,)
+    if typing.get_origin(dtype) in [list, tuple]:
+        if not __has_ellipsis_in_types(dtype):
+            max_x = len(typing.get_args(dtype))
+        types_are_uniform = __check_types_uniformity(dtype)
+        dtype = typing.get_args(dtype)[0]
+        dformat = (
+            AttrDataFormat.IMAGE
+            if typing.get_origin(dtype) in [list, tuple]
+            else AttrDataFormat.SPECTRUM
+        )
+
+        if caller in ["property", "command"] and dformat == AttrDataFormat.IMAGE:
+            raise RuntimeError(f"{caller.capitalize()} does not support IMAGE type")
+
+        if not types_are_uniform:
+            if caller in ["property", "command"]:
+                raise RuntimeError(
+                    f"PyTango does not support mixed types in SPECTRUM {caller}"
+                )
+            else:
+                if dformat == AttrDataFormat.IMAGE:
+                    raise RuntimeError(
+                        "PyTango does not support mixed types in IMAGE attributes"
+                    )
+                else:
+                    raise RuntimeError(
+                        "PyTango does not support mixed types in SPECTRUM attributes"
+                    )
+
+        if caller == "attribute":
+            if dformat == AttrDataFormat.IMAGE:
+                max_y = max_x
+                if not __has_ellipsis_in_types(dtype):
+                    max_x = len(typing.get_args(dtype))
+                else:
+                    max_x = None
+                dtype = typing.get_args(dtype)[0]
+        if caller == "property":
+            dtype = (dtype,)
+
+    return dtype, dformat, max_x, max_y
 
 
 class EnumTypeError(Exception):
@@ -1523,7 +1636,7 @@ def _notifd2db_file_db(ior_string, files, out=sys.stdout):
 
 
 def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
-    from . import Database
+    from tango import Database
 
     print(
         "going to export notification service event factory to Tango database ...",
@@ -1792,7 +1905,7 @@ def from_version_str_to_int(version_str):
 
 def info():
     # Compile and Runtime are set by `tango.pytango_init.init`
-    from .constants import Compile, Runtime
+    from tango.constants import Compile, Runtime
 
     msg = f"""\
 PyTango {Release.version_long} {Release.version_info}
@@ -1884,3 +1997,95 @@ class PyTangoHelpFormatter(HelpFormatter):
             pass
 
         return usage
+
+
+__TEST_CONTEXT_HOST_TRL = None
+
+
+def _set_test_context_tango_host_fqtrl(host_trl):
+    """For PyTango internal use only!"""
+    # NOTE: we only keep one value so if multiple TestContexts are started in
+    # the same process, only the latest one will be used
+    if host_trl is not None:
+        global __TEST_CONTEXT_HOST_TRL
+        __TEST_CONTEXT_HOST_TRL = host_trl
+
+
+def _clear_test_context_tango_host_fqtrl():
+    """For PyTango internal use only!"""
+    global __TEST_CONTEXT_HOST_TRL
+    __TEST_CONTEXT_HOST_TRL = None
+
+
+def _get_test_context_tango_host_fqtrl():
+    """For PyTango internal use only!"""
+    return __TEST_CONTEXT_HOST_TRL
+
+
+def _get_device_fqtrl_if_necessary(device_trl):
+    """For PyTango internal use only!"""
+    if __TEST_CONTEXT_HOST_TRL:
+        device_trl = _get_device_fqtrl(device_trl, __TEST_CONTEXT_HOST_TRL)
+    return device_trl
+
+
+def _get_device_fqtrl(device_trl, host_trl):
+    parsed_device = urlparse(device_trl)
+    if not _is_tango_uri_resolved(parsed_device):
+        parsed_host = urlparse(host_trl)
+        device_trl = _try_resolve_tango_trl(parsed_host, parsed_device)
+    return device_trl
+
+
+def _is_tango_uri_resolved(parsed_device):
+    return parsed_device.scheme == "tango"
+
+
+def _try_resolve_tango_trl(parsed_host, parsed_device):
+    if not _is_valid_tango_trl(parsed_host):
+        raise InvalidTangoHostTrlError(
+            f"Invalid form for Tango host: {parsed_host!r}, device {parsed_device!r}. "
+            f"(Override set to: {__TEST_CONTEXT_HOST_TRL})."
+        )
+    return _resolve_tango_trl(parsed_host, parsed_device)
+
+
+def _is_valid_tango_trl(parsed_host):
+    scheme_ok = parsed_host.scheme == "tango"
+    hostname_ok = bool(parsed_host.hostname)
+    port_ok = bool(parsed_host.port)
+    path_ok = parsed_host.path == ""
+    params_ok = parsed_host.params == ""
+    query_ok = parsed_host.query == ""
+    fragment_ok = parsed_host.fragment in ["", "dbase=no", "dbase=yes"]
+    return (
+        scheme_ok
+        and hostname_ok
+        and port_ok
+        and path_ok
+        and params_ok
+        and query_ok
+        and fragment_ok
+    )
+
+
+def _resolve_tango_trl(parsed_host, parsed_device):
+    return urlunparse(
+        [
+            parsed_host.scheme,
+            parsed_host.netloc,
+            parsed_device.path,
+            parsed_host.params,
+            parsed_host.query,
+            parsed_host.fragment,
+        ]
+    )
+
+
+class InvalidTangoHostTrlError(ValueError):
+    """Invalid Tango Resource Locator format for TANGO_HOST-like variable."""
+
+
+class PyTangoUserWarning(UserWarning):
+    # a custom category for all PyTango's warnings to give users the option of filtering PyTango's warnings
+    pass
