@@ -1,10 +1,14 @@
 import os
-import pytest
-import tango
+import warnings
 
 import numpy as np
+import pytest
+import tango
+import asyncio
+import gevent.event
+import concurrent.futures
 
-from tango import AttrWriteType, GreenMode
+from tango import AttrWriteType, DevFailed, GreenMode, get_device_proxy, DeviceProxy
 from tango.asyncio_executor import AsyncioExecutor
 from tango.device_server import get_worker
 from tango.gevent_executor import GeventExecutor
@@ -25,18 +29,21 @@ WINDOWS = "nt" in os.name
 
 class Device1(Device):
     def init_device(self):
-        super(Device, self).init_device()
+        super().init_device()
         self.set_state(tango.DevState.ON)
         self._attr1 = 100
 
-    @attribute
+    @attribute(access=AttrWriteType.READ_WRITE)
     def attr1(self):
         return self._attr1
 
+    def write_attr1(self, value):
+        self._attr1 = value
+
 
 class Device2(Device):
     def init_device(self):
-        super(Device, self).init_device()
+        super().init_device()
         self.set_state(tango.DevState.ON)
         self._attr2 = 200
 
@@ -45,6 +52,17 @@ class Device2(Device):
         return self._attr2
 
 
+class Device3(Device):
+    def init_device(self):
+        super().init_device()
+        self.my_proxy = tango.DeviceProxy("test/device1/1")
+        self.set_state(tango.DevState.ON)
+
+    @attribute
+    def attr3(self):
+        return self.my_proxy.attr1
+
+
 class Device1GreenModeUnspecified(Device1):
     pass
 
@@ -85,6 +103,15 @@ class Device1AsyncInit(Device1):
         self._attr1 = 150
 
 
+def test_no_warnings_in_test_context():
+    class TestDevice(Device):
+        ...
+
+    warnings.filterwarnings("error")
+    with DeviceTestContext(TestDevice):
+        pass
+
+
 def test_single_device(server_green_mode):
     class TestDevice(Device1):
         green_mode = server_green_mode
@@ -105,6 +132,30 @@ def test_single_device_old_api():
         assert proxy.attr1 == 100
 
 
+def test_nested_single_device_in_same_process_failure():
+    # Nesting not recommended - use MultiDeviceTestContext
+    with DeviceTestContext(Device1, process=False):
+        with pytest.raises(DevFailed):
+            with DeviceTestContext(Device2, process=False):
+                pass
+
+
+def test_nested_single_device_in_different_processes_success_without_short_names():
+    # Nesting not recommended - use MultiDeviceTestContext
+    with DeviceTestContext(Device1, process=True) as proxy1:
+        with DeviceTestContext(Device2, process=True) as proxy2:
+            assert proxy1.attr1 == 100
+            assert proxy2.attr2 == 200
+
+
+def test_nested_single_device_in_different_processes_failure_with_short_names():
+    # Nesting not recommended - use MultiDeviceTestContext
+    with DeviceTestContext(Device1, device_name="test/nodb/1", process=True):
+        with DeviceTestContext(Device2, process=True):
+            with pytest.raises(DevFailed):
+                tango.DeviceProxy("test/nodb/1")
+
+
 @pytest.mark.parametrize(
     "class_field, device",
     [
@@ -378,7 +429,7 @@ def test_multi_with_async_devices_initialised():
         assert proxy2.attr2 == 200
 
 
-def test_multi_device_access():
+def test_multi_device_access_via_test_context_methods():
     devices_info = (
         {"class": Device1, "devices": [{"name": "test/device1/1"}]},
         {"class": Device2, "devices": [{"name": "test/device2/2"}]},
@@ -399,6 +450,116 @@ def test_multi_device_access():
         assert proxy_server.State() == tango.DevState.ON
 
 
+def test_multi_short_name_device_proxy_access_without_tango_db():
+    devices_info = ({"class": Device1, "devices": [{"name": "test/device1/1"}]},)
+
+    with MultiDeviceTestContext(devices_info, process=True):
+        proxy1 = tango.DeviceProxy("test/device1/1")
+        assert proxy1.name() == "test/device1/1"
+        assert proxy1.attr1 == 100
+
+
+def test_multi_short_name_device_proxy_with_dependencies_access_without_tango_db():
+    devices_info = (
+        {"class": Device1, "devices": [{"name": "test/device1/1"}]},
+        {"class": Device3, "devices": [{"name": "test/device3/3"}]},
+    )
+
+    with MultiDeviceTestContext(devices_info, process=True):
+        proxy1 = tango.DeviceProxy("test/device1/1")
+        proxy3 = tango.DeviceProxy("test/device3/3")
+        assert proxy1.name() == "test/device1/1"
+        assert proxy1.attr1 == 100
+        assert proxy3.name() == "test/device3/3"
+        assert proxy3.attr3 == 100
+        proxy1.attr1 = 300
+        assert proxy3.attr3 == 300
+
+
+def test_multi_short_name_attribute_proxy_access_without_tango_db():
+    devices_info = ({"class": Device1, "devices": [{"name": "test/device1/1"}]},)
+
+    with MultiDeviceTestContext(devices_info):
+        attr1 = tango.AttributeProxy("test/device1/1/attr1")
+        assert attr1.name() == "attr1"
+        assert attr1.read().value == 100
+
+
+def test_single_short_name_device_proxy_access_without_tango_db():
+    with DeviceTestContext(Device1, device_name="test/device1/1"):
+        proxy1 = tango.DeviceProxy("test/device1/1")
+        assert proxy1.name() == "test/device1/1"
+        assert proxy1.attr1 == 100
+
+
+def test_single_short_name_attribute_proxy_access_without_tango_db():
+    with DeviceTestContext(Device1, device_name="test/device1/1"):
+        attr1 = tango.AttributeProxy("test/device1/1/attr1")
+        assert attr1.name() == "attr1"
+        assert attr1.read().value == 100
+
+
+def test_multi_short_name_group_access_without_tango_db():
+    devices_info = (
+        {
+            "class": Device1,
+            "devices": [{"name": "test/device1/1"}, {"name": "test/device1/2"}],
+        },
+    )
+
+    with MultiDeviceTestContext(devices_info) as context:
+        group_singles = tango.Group("add-one-at-a-time")
+        group_singles.add("test/device1/1")
+        group_singles.add("test/device1/2")
+        group_multiples_list = tango.Group("add-multiple-via-list")
+        group_multiples_list.add(["test/device1/1", "test/device1/2"])
+        group_multiples_vector = tango.Group("add-multiple-via-std-vector")
+        vector = tango.StdStringVector()
+        vector.append("test/device1/1")
+        vector.append("test/device1/2")
+        group_multiples_vector.add(vector)
+        group_in_group = tango.Group("add-sub-group")
+        group_in_group.add(group_singles)
+
+        groups = [
+            group_singles,
+            group_multiples_list,
+            group_multiples_vector,
+            group_in_group,
+        ]
+
+        device1_fqdn = context.get_device_access("test/device1/1")
+        device2_fqdn = context.get_device_access("test/device1/2")
+        for group in groups:
+            assert device1_fqdn in group
+            assert device2_fqdn in group
+            reply = group.read_attribute("attr1")
+            assert reply[0].dev_name() == device1_fqdn
+            assert reply[1].dev_name() == device2_fqdn
+            assert not reply[0].has_failed()
+            assert not reply[1].has_failed()
+            assert reply[0].get_data().value == 100
+            assert reply[1].get_data().value == 100
+
+        # patterns are not supported via DeviceTestContext
+        with pytest.raises(tango.DevFailed):
+            group_multiples_pattern = tango.Group("add-multiple-via-pattern")
+            group_multiples_pattern.add("test/device1/*")
+
+
+def test_multi_short_name_access_fails_if_override_disabled():
+    devices_info = ({"class": Device1, "devices": [{"name": "test/device1/a"}]},)
+
+    context = MultiDeviceTestContext(devices_info, process=True)
+    context.enable_test_context_tango_host_override = False
+    context.start()
+    try:
+        with pytest.raises(DevFailed):
+            _ = tango.DeviceProxy("test/device1/a")
+    finally:
+        context.stop()
+
+
 def test_multi_device_proxy_cached():
     devices_info = ({"class": Device1, "devices": [{"name": "test/device1/1"}]},)
 
@@ -606,3 +767,186 @@ def test_empty_string_property_bug(property_type, property_value, expected_outco
 
     with DeviceTestContext(TestDevice, properties=property_value) as proxy:
         assert proxy.attr == expected_outcome
+
+
+class AsyncDevice(Device):
+    green_mode = GreenMode.Asyncio
+    _value = 0
+    _my_proxy = None
+
+    @attribute
+    async def value(self):
+        return self._value
+
+    @command(dtype_out="DevShort")
+    async def increment(self):
+        await asyncio.sleep(0.1)
+        self._value += 1
+        return self._value
+
+    @attribute(dtype=str)
+    async def my_name(self):
+        return self.get_name()
+
+    @attribute(dtype=str)
+    async def child_name(self):
+        attr = await self._my_proxy.read_attribute("my_name")
+        return attr.value
+
+    @command(dtype_in="DevString")
+    async def connect_to_device(self, fqdn):
+        proxy_future = get_device_proxy(fqdn, green_mode=GreenMode.Asyncio)
+        assert isinstance(proxy_future, asyncio.Future)
+
+        self._my_proxy = await proxy_future
+        assert isinstance(self._my_proxy, DeviceProxy)
+
+
+@pytest.mark.asyncio
+@pytest.mark.parametrize("process", [True, False])
+async def test_test_context_async_device_proxy(process):
+    config = ({"class": AsyncDevice, "devices": [{"name": "test/device/1"}]},)
+
+    with MultiDeviceTestContext(config, process=process) as context:
+        fq_name = context.get_device_access("test/device/1")
+
+        proxy_future = get_device_proxy(fq_name, green_mode=GreenMode.Asyncio)
+        assert isinstance(proxy_future, asyncio.Future)
+
+        proxy = await proxy_future
+        assert isinstance(proxy, DeviceProxy)
+
+        assert proxy.get_green_mode() == GreenMode.Asyncio
+
+        # Ensure that we use the correct access method for the DeviceProxy call
+        value = await proxy.increment()
+        assert value == 1
+
+        # Ensure that we use the correct access method for the DeviceProxy call
+        attr = await proxy.read_attribute("value")
+        assert attr.value == 1
+
+
+@pytest.mark.asyncio
+@pytest.mark.parametrize("process", [True, False])
+async def test_test_context_multi_async_device_proxy(process):
+    config = (
+        {
+            "class": AsyncDevice,
+            "devices": [{"name": "test/device/main"}, {"name": "test/device/child"}],
+        },
+    )
+
+    with MultiDeviceTestContext(config, process=process) as context:
+        fq_name_main = context.get_device_access("test/device/main")
+        fq_name_child = context.get_device_access("test/device/child")
+
+        proxy_future_main = get_device_proxy(fq_name_main, green_mode=GreenMode.Asyncio)
+        assert isinstance(proxy_future_main, asyncio.Future)
+
+        proxy_main = await proxy_future_main
+        assert isinstance(proxy_main, DeviceProxy)
+
+        assert proxy_main.get_green_mode() == GreenMode.Asyncio
+
+        proxy_future_child = get_device_proxy(
+            fq_name_child, green_mode=GreenMode.Asyncio
+        )
+        assert isinstance(proxy_future_child, asyncio.Future)
+
+        proxy_child = await proxy_future_child
+        assert isinstance(proxy_child, DeviceProxy)
+
+        # Ensure that we use the correct access method for the DeviceProxy call
+        await proxy_main.connect_to_device(fq_name_child)
+
+        attr = await proxy_main.read_attribute("my_name")
+        assert attr.value == "test/device/main"
+
+        attr = await proxy_main.read_attribute("child_name")
+        assert attr.value == "test/device/child"
+
+
+class FutureAndGeventDevice(Device):
+    green_mode = None
+    _value = 0
+
+    @attribute
+    def value(self):
+        return self._value
+
+    @command(dtype_out="DevShort")
+    def increment(self):
+        self._value += 1
+        return self._value
+
+
+@pytest.mark.parametrize("test_green_mode", [GreenMode.Futures, GreenMode.Gevent])
+@pytest.mark.parametrize("process", [True, False])
+def test_test_context_future_and_gevent_device_proxy(test_green_mode, process):
+    FutureAndGeventDevice.green_mode = test_green_mode
+
+    if test_green_mode == GreenMode.Futures:
+        accessor = "result"
+        expected_type = concurrent.futures.Future
+    elif test_green_mode == GreenMode.Gevent:
+        accessor = "get"
+        expected_type = gevent.event.AsyncResult
+    else:
+        raise RuntimeError("Wrong GreenMode")
+
+    config = ({"class": FutureAndGeventDevice, "devices": [{"name": "test/device/1"}]},)
+
+    with MultiDeviceTestContext(config, process=process) as context:
+        fq_name = context.get_device_access("test/device/1")
+
+        proxy_future = get_device_proxy(fq_name, green_mode=test_green_mode, wait=False)
+        assert isinstance(proxy_future, expected_type)
+
+        proxy = getattr(proxy_future, accessor)()
+        assert isinstance(proxy, DeviceProxy)
+
+        assert proxy.get_green_mode() == test_green_mode
+
+        # Ensure that we use the correct access method for the DeviceProxy call
+        value_future = proxy.increment(wait=False)
+        assert isinstance(value_future, expected_type)
+        assert getattr(value_future, accessor)() == 1
+
+        # Ensure that we use the correct access method for the DeviceProxy call
+        attr_future = proxy.read_attribute("value", wait=False)
+        assert isinstance(attr_future, expected_type)
+        assert attr_future.result().value == 1
+
+
+class FwdServer(Device):
+    fwd_attr = attribute(forwarded=True)
+
+
+@pytest.mark.parametrize("process", [True, False])
+def test_forwarded_attributes(process):
+    pytest.xfail(
+        "Does not work yet - see https://gitlab.com/tango-controls/cppTango/-/issues/796"
+    )
+    devices_info = (
+        {"class": Device1, "devices": [{"name": "test/device1/1"}]},
+        {
+            "class": FwdServer,
+            "devices": [
+                {
+                    "name": "test/fwdserver/1",
+                    "root_atts": {"fwd_attr": "test/device1/1/attr1"},
+                }
+            ],
+        },
+    )
+
+    with MultiDeviceTestContext(devices_info, process=process):
+        proxy_root = tango.DeviceProxy("test/device1/1")
+        proxy_fwd = tango.DeviceProxy("test/fwdserver/1")
+        assert "fwd_attr" in proxy_fwd.get_attribute_list()
+        assert proxy_fwd.fwd_attr == 100
+        proxy_fwd.fwd_attr = 200
+        assert proxy_root.attr1 == 200
+        proxy_root.attr1 = 300
+        assert proxy_fwd.fwd_attr == 300
